\name{webImport}

\alias{webImport}

\alias{economagicImport}
\alias{yahooImport}
\alias{keystatsImport}

\title{Import Market Data from the Internet}


\description{
	
	A collection of functions to import financial and economic market 
	from the Internet.
	\cr
	
	The functions are:
	
	\tabular{rll}{
		1	\tab  	\code{economagicImport}	
			\tab  	Economic time series from Economagic's Web site, \cr
		2	\tab  	\code{yahooImport} 		
			\tab  	Daily stock market data from Yahoo's Web site, \cr
		3	\tab  	\code{keystatsImport} 		
			\tab  	Key Statistics on Shares from Yahoo's Web site. }

}


\usage{
economagicImport(file = "tempfile", 
	source = "http://www.economagic.com/em-cgi/data.exe/", query, 
	frequency = c("quarterly", "monthly", "daily"), save = FALSE, 
	colname = "VALUE", try = TRUE)
	
yahooImport(file = "tempfile", 
  	source = "http://chart.yahoo.com/table.csv?", query, save=FALSE,
  	try = TRUE)
keystatsImport(file = "tempfile", 
    source = "http://finance.yahoo.com/q/ks?s=", query, save = FALSE, 
    try = TRUE) 
}


\arguments{

	\item{colname}{
		a character string which defines the name of the value
		column. By default "VALUE".
		}
	\item{file}{
		a character string with filename, usually
		having extension ".csv", where to save the downloaded data.
		}
	\item{frequency}{
		a character string, one of "quarterly", "monthly", or "daily",
		defining the frequency of the data records.
		}
	\item{query}{
		a character string, denoting the location of the data at the web site.
		}
	\item{save}{
		a logical value, if set to TRUE the downloaded data file will be
		stored under the path and file name specified by the
		string \code{file}. By default FALSE.
		}
	\item{source}{
		a character string with the download URL.
		}
	\item{try}{
		a logical value, if set to TRUE the Internet access will be
		checked.
		}
		
}


\value{

	A data frame with the downloaded data records or key statistics.
	
}


\details{

  	\bold{Import data from www.economagic.com}
  	\cr\cr
	Frequently requested data files from Economagic for the US economy include:

	\tabular{ll}{
	\code{[query]}                    \tab Description: \cr
				          			  \tab \cr
	\code{var/leading-ind-long}       \tab Index of Leading Economic Indicators  \cr
	\code{beana/t102l01}              \tab Real Gross Domestic Product  \cr
	\code{fedstl/trsp500}             \tab SP 500 Total Return \cr
	\code{fedstl/gnp}                 \tab Gross National Product in Current Dollars \cr
	\code{var/cpiu-long}              \tab Consumer Price Index - All Urban Consumers \cr
	\code{feddal/ru}                  \tab Unemployment Rate \cr
	\code{fedstl/indpro}              \tab Total Industrial Production Index \cr
	\code{fedstl/exjpus+2}            \tab FX Rate: Japanese Yen to one US Dollar \cr
	\code{fedstl/fedfunds+2}          \tab Federal Funds Rate \cr
	\code{fedstl/mdiscrt+2}           \tab Discount Rate \cr
	\code{fedbog/tcm30y+2}            \tab 30-Year Treasury Constant Maturity Rate \cr
	\code{fedstl/mprime+2}            \tab Bank Prime Loan Rate \cr
	\code{fedstl/tb3ms+2}             \tab 3-Month Treasury Bills - Secondary Market \cr
	\code{fedstl/tb6ms+2}             \tab 6-Month Treasury Bills - Secondary Market \cr
	\code{fedbog/cm+2}                \tab 30 Year Federal Home Loan Mortgages \cr
	\code{var/west-texas-crude-long}  \tab Price of West Texas Intermediate Crude }

  
	\bold{Import data from chart.yahoo.com:}
  	\cr\cr
	The query string is given as 
	\cr\cr
			\code{s=SYMBOL&a=DD&b=MM&c=CCYY&g=d&q=q&z=SYMBOL&x=.csv} 
	\cr\cr
	where \code{SYMBOL} has to replaced by the symbol name of the 
	instrument, and \code{DD}, \code{MM}, and \code{CCYY} by the 
	day, month-1 and century/year when the time series should start.

	Here are some examples of symbols:

	\tabular{ll}{
	\code{[query]}	\tab Description: \cr
					\tab \cr
	\code{^DJI}		\tab Dow Jones 30 Industrial Averages \cr
	\code{^NYA}		\tab New York Stock Exchange Composite \cr
	\code{^NDX}		\tab Nasdaq 100 Index \cr
	\code{^IXIC}	\tab Nasdaq Composite Index \cr
	\code{^TYX}		\tab US 30Y Treasury Bond Index \cr
	\code{IBM}		\tab BM DJIA Stock \cr
	\code{KO}		\tab Coca-Cola DJIA Stock }

	The meaning of the tokens in the query string are the following:

	\tabular{ll}{
	Token			\tab Description  \cr
					\tab \cr
	\code{s}		\tab Selected Ticker-Symbol \cr
	\code{a}		\tab First Quote starts with Month (mm) \cr
	\code{b}		\tab First Quote starts with Day (dd) \cr
	\code{c}		\tab First Quote starts with Year (ccyy) \cr
	\code{d}		\tab Last Quote ends with Month (mm) \cr
	\code{e}		\tab Last Quote ends with Day (dd) \cr
	\code{f}		\tab Last Quote ends with Year (ccyy) \cr
	\code{z}		\tab Selected Ticker-Symbol }

	Month tokens range between 0 and 11 for January to December!
	
	
	\bold{Key Statistics data from finance.yahoo.com:}
  	\cr\cr
  	The functions downloads the key statistics for the specified
  	equity query and returns the result as a two column data frame. 
  	The key names included are: "Market Cap", "Enterprise Value",
	"Trailing P/E", "Forward P/E", "PEG Ratio", "Price/Sales",
	"Price/Book", "Enterprise Value/Revenue", "Enterprise Value/EBITDA",
	"Annual Dividend", "Dividend Yield", "Beta",
    "52-Week Change", "52-Week High", and "52-Week Low".
			
}


\notes{
  
 	Note, that if the service provider changes the data file format 
 	it may become necessary to modify and update the function. 
  
	The import function for the Chicago Fed will be replaced in a 
	future version of \code{fBasics} with a function for the St. 
	Louis Fed which offers a much broader database of financial 
	and economic market data
	
	For compatibility with Splus naming conventions the following 
	synonyme function calls \code{import.data.chicagofed}, 
	\code{import.data.economagic}, and \code{import.data.yahoo} can 
	be used.
  
  	The R package \code{tseries} from Adrian Trapletti offers an 
  	alternative function to download stock market data and indexes 
  	from Yahoo's Internet site.
  
}


\examples{
\dontrun{
   
## economagicImport -
   xmpBasics("\nStart: Daily Foreign Exchange Rates > ")
   USDEUR = economagicImport(query = "fedny/day-fxus2eu", 
   	 frequency = "daily", colname = "USDEUR", try = TRUE)
   # Print if Internet Download was Successful:
   if(!is.null(USDEUR)) print(USDEUR[1:20, ])

## economagicImport -
   xmpBasics("\nNext: USFEDFUNDS Monthly US FedFunds Rates > ")
   USFEDFUNDS = economagicImport(query = "fedstl/fedfunds+2", 
   	 frequency = "monthly", colname = "USFEDFUNDS", try = TRUE)
   if(!is.null(USFEDFUNDS)) print(USFEDFUNDS[1:20, ])
   
## economagicImport -
   xmpBasics("\nNext: USDGNP Quarterly GNP Data Records > ")
   USGNP = economagicImport(query = "fedstl/gnp", 
   	 frequency = "quarterly", colname = "USGNP", try = TRUE)
   if(!is.null(USGNP)) print(USGNP[1:20, ])  
     
## yahooImport -
   xmpBasics("\nNext: IBM Shares from Yahoo > ")
   # [test 19/20 century change 01-12-1999 -- 31-01-2000]
   IBM = yahooImport(
   	 query = "s=IBM&a=11&b=1&c=1999&d=0&q=31&f=2000&z=IBM&x=.csv", 
   	 try = TRUE)
   if (!is.null(IBM)) print(IBM[1:20, ])
   
## keystatsImport -
   xmpBasics("\nNext: Key Statistics IBM Shares from Yahoo > ")  
   keystatsImport(query = "IBM"   
}
}

\author{

	Diethelm Wuertz for this \R-port.
}


\keyword{data}


\eof
\name{basicStatistics}

\alias{basicStatistics}

\alias{basicStats}

\alias{skewness}
\alias{skewness.default}
\alias{skewness.data.frame}
\alias{skewness.POSIXct}
\alias{skewness.POSIXlt}

\alias{kurtosis}
\alias{kurtosis.default}
\alias{kurtosis.data.frame}
\alias{kurtosis.POSIXct}
\alias{kurtosis.POSIXlt}

\alias{rowStats} 
\alias{rowAvgs}
\alias{rowVars}
\alias{rowStdevs}
\alias{rowSkewness}
\alias{rowKurtosis}
\alias{rowCumsums}

\alias{colStats} 
\alias{colAvgs}
\alias{colVars}
\alias{colStdevs}
\alias{colSkewness}
\alias{colKurtosis}
\alias{colCumsums}

\title{Basic Statistics Summary}


\description{

	A collection of functions which compute basic statistical properties. 
	Missing functions in R to calculate skewness and kurtosis are added, 
	a function which creates a summary statistics, and functions to calculate 
	column statistcs.
	\cr
	
	The functions are:
	
	\tabular{rll}{
		1	\tab 	\code{skewness} 		
			\tab 	Returns value of skewness, \cr
		2	\tab 	\code{kurtosis} 		
			\tab 	Returns value of kurtosis, \cr	
		3	\tab 	\code{basicStats} 	
			\tab 	Computes an overview of basic statistical values, \cr	
		4	\tab 	\code{rowStats}, \code{colStats} 		
			\tab 	Calculates row/column statistics, \cr
		5	\tab 	\code{rowAvgs}, \code{colAvgs} 		
			\tab 	Calculates row/column means, \cr
		6	\tab 	\code{rowVars}, \code{colVars} 		
			\tab 	Calculates row/column variances, \cr
		7	\tab 	\code{rowStdevs}, \code{colStdevs} 		
			\tab 	Calculates row/column standard deviations, \cr
		8	\tab 	\code{rowSkewness}, \code{colSkewness} 	
			\tab 	Calculates row/column skewness, \cr
		9	\tab 	\code{rowKurtosis}, \code{colKurtosis} 	
			\tab 	Calculates row/column kurtosis, \cr
	   10 	\tab 	\code{rowCumsums}, \code{colCumsums} 	
	   		\tab 	Calculates row/column cumulated Sums. }
}


\usage{
skewness(x, \dots)
\method{skewness}{default}(x, na.rm = FALSE, \dots)
\method{skewness}{data.frame}(x, \dots)
\method{skewness}{POSIXct}(x, \dots)
\method{skewness}{POSIXlt}(x, \dots)

kurtosis(x, \dots)
\method{kurtosis}{default}(x, na.rm = FALSE, \dots)
\method{kurtosis}{data.frame}(x, \dots)
\method{kurtosis}{POSIXct}(x, \dots)
\method{kurtosis}{POSIXlt}(x, \dots)

basicStats(x, ci = 0.95)

rowStats(x, FUN, na.rm = FALSE, \dots) 
rowAvgs(x, na.rm = FALSE, \dots)
rowVars(x, na.rm = FALSE, \dots)
rowStdevs(x, na.rm = FALSE, \dots)
rowSkewness(x, na.rm = FALSE, \dots)
rowKurtosis(x, na.rm = FALSE, \dots)
rowCumsums(x, na.rm = FALSE, \dots)

colStats(x, FUN, na.rm = FALSE, \dots) 
colAvgs(x, na.rm = FALSE, \dots)
colVars(x, na.rm = FALSE, \dots)
colStdevs(x, na.rm = FALSE, \dots)
colSkewness(x, na.rm = FALSE, \dots)
colKurtosis(x, na.rm = FALSE, \dots)
colCumsums(x, na.rm = FALSE, \dots)
}


\arguments{
  
	\item{ci}{
		confidence interval, a numeric value, by default 0.95, 
		i.e. 95 percent.
		}
	\item{FUN}{
	    the statistical function to be applied.
	    }
		\item{na.rm}{
		a logical. Should missing values be removed?
		}
	\item{x}{
		a numeric vector, or a matrix for column statistics.
		}
	\item{\dots}{
	    arguments to be passed.
	    }
	    
}


\value{
	
	\code{skewness}, \code{kurtosis}
	\cr
	returns the value of the statistics, a numeric value.
	\cr
	
	\code{basicsStats}
	\cr
	returns data frame with the following entries and row names:
	nobs, NAs, Minimum, Maximum , 1. Quartile, 3. Quartile,
	Mean, Median, Sum, SE Mean, LCL Mean, UCL Mean, Variance,
	Stdev, Skewness, Kurtosis.
	\cr
	
	\code{rowStats}, \code{rowAvgs}, \code{rowVars}, \code{rowStdevs},\cr
	\code{rowSkewness}, \code{rowKurtosis}, \code{rowCumsum}
	\cr 
	computes sample statistics by column. Missing values can be
	handled.
	\cr
	
	\code{colStats}, \code{colAvgs}, \code{colVars}, \code{colStdevs},\cr
	\code{colSkewness}, \code{colKurtosis}, \code{colCumsum}
	\cr 
	computes sample statistics by column. Missing values can be
	handled. 
	
}


\note{

	\R's-base package contains a function \code{colMeans} with an
	additional argument \code{dim=1}. Therefore, the function used 
	here to compute column means (averages) is named \code{colAvgs}.
	
}


\author{

	Diethelm Wuertz for this \R-port.
	
}


\seealso{

	\code{\link{colMeans}},
	\code{\link{mean}},
	\code{\link{median}},
	\code{\link{var}}.
	
}


\examples{
## basicStats -
   xmpBasics("\nStart: Basic Statistics of log-Returns > ")
   # Data NYSE Composite Index:
   data(nyseres)
   basicStats(nyseres)  
     
## moments -
   xmpBasics("\nNext: Moments, Skewness and Kurtosis > ")
   # Mean, Variance:
   mean(nyseres)
   var(nyseres)
   # Skewness, Kurtosis:
   # Note, can handele data.frames:
   skewness(nyseres)
   kurtosis(nyseres)   
}


\keyword{univar}


\eof
\name{basicPlots}

\alias{basicPlots}

\alias{tsPlot}
\alias{histPlot}
\alias{densityPlot}
\alias{circlesPlot}
\alias{perspPlot}

\alias{characterTable}
\alias{plotcharacterTable}
\alias{colorTable}

\alias{splusLikePlot}


\title{Basic Plot Functions and Utilities}


\description{ 

	A collection of several plot functions and utilities which may
	be useful for the explorative data analysis of financial and 
	economic market data. Listed are also three utility functions
	displaying tables for characters, plot symbols, and colors.
    \cr
    
    The functions are:
	
	\tabular{rll}{
		1 	\tab 	\code{tsPlot} 			
			\tab 	Time Series Plot, \cr
		2 	\tab 	\code{histPlot}   		
			\tab 	Histogram Plot of (Series) Data, \cr
		3 	\tab 	\code{densityPlot} 		
			\tab 	Kernel Density Estimate Plot, \cr
		4 	\tab 	\code{circlesPlot} 		
			\tab 	Scatterplot of Circles Indexing a 3rd Variable, \cr
		5 	\tab 	\code{perspPlot} 			
			\tab 	Perspective Plot in 2 Dimensions, \cr
		6 	\tab 	\code{characterTable}		
			\tab 	Table of Numerical Equivalents to Latin Characters, \cr
		7 	\tab 	\code{plotcharacterTable}	
			\tab 	Table of plot characters, plot symbols, \cr
		8 	\tab 	\code{colorTable} 		
			\tab 	Table of Color Codes and Plot Colors itself, \cr
		9 	\tab 	\code{splusLikePlot}		
			\tab 	Scales plotting and symbols.}
	
}


\usage{ 
tsPlot(x, type = "l", labels = TRUE, \dots) 
histPlot(x, col = "steelblue4", border = "white", \dots)
densityPlot(x, \dots)
circlesPlot(x, y, size = 1, \dots)
perspPlot(x, y, z, theta = -40, phi = 30, col = "steelblue4", ps = 9, \dots)

characterTable(font = 1, cex = 0.7)
plotcharacterTable(font = par('font'), cex = 0.7)
colorTable(cex = 0.7)

splusLikePlot(scale = 0.8))
}


\arguments{
  
	\item{col, border, type}{
	  	two character strings, defining the colors used to fill the
	  	bars and to plot the borders of the bars for the \code{histPlot},
	  	or color and linetype as used by the function \code{plot}.
	  	}
	\item{font, cex}{
		an integer value, the number of the \code{font}, by default font 
		number 1, the standard font for the \code{characterTable}
		or the current plot character font for the 
		\code{plotcharacterTable}. The character size is determined by
		the numeric value \code{cex}, the default size is 0.7.
		}	
	\item{labels}{
		a logical. If set to \code{TRUE} labels are generated automatically,
		otherwise not. Default value is \code{TRUE}.
		}	
	\item{scale}{
		a numeric value, by default 0.8, to scale fonts and symbols in
		plots to make them more Splus like.
		}
	\item{size}{
		a numeric vector like \code{z}, the third variable in the 
		function \code{circlesPlot}. The argument gives the size of the 
		circles, by default all values are set to 1.
		}
	\item{theta, phi, ps}{
	  	plot parameters for the function \code{perspPlot} as used by the
	  	function \code{persp}.
	  	}
	\item{x, y}{
		numeric vectors.
		In the case of the \code{thermometerPlot} \code{x} holds the
		current values of the n-bars.
		}
	\item{z}{
	    a matrix containing the values to be plotted by the function
	    \code{perspPlot}.
	    }
	\item{\dots}{
	    arguments to be passed to the underlying plot function.
	    }
    
}


\value{
	
	\code{tsPlot}
	\cr
	plots a time series. Just a synonyme call to the function
	\code{ts.plot} changing plot type to \code{l}ines and plot color 
	to \code{steelblue3}.
	\cr
	
	\code{histPlot}
	\cr
	plots a histogram. This is a synonyme function call for R's 
	histogram plot, calling the function \code{hist}. Returns an 
	object of class \code{"histogram"}, see \code{hist}.
	\cr
	
	\code{densityPlot}
	\cr
	returns an object of class \code{"density"}, see \code{density}.
	\cr
	
	\code{circlesPlot}
	\cr
	a simple pseudo three dimensional scatterplot of circels whose
	sizes index a thrid variable.
	\cr
	
	\code{perspPlot}
	\cr
	draws perspective plots of surfaces over the x-y plane.
	\cr
	
	\code{characterTable}
	\cr
	displays a table with the characters of the requested font.
  	The character on line "xy" and column "z" of the table has 
  	code \code{"\xyz"}, e.g \code{cat("\\126")} prints: V for font 
  	number 1. These codes can be used as any other characters.
  	\cr 
  	
  	\code{plotcharacterTable}
  	\cr
  	displays a table with the plot characters numbered from 0 to 255.
  	\cr
  	
  	\code{colorTable}
  	\cr
    displays a table with the plot colors with the associated color number.
    \cr
    
    \code{splusLikePlot}
    \cr	 
    scales plotting and symbols to make plots more Splus like.
    
}


\details{

	\bold{Series Plots:}
	\cr\cr
	\code{tsPlot} plots time series on a common plot. Unlike \code{plot.ts} 
	the series can have a different time bases, but they should have the 
	same frequency. \code{tsPlot} is a synonyme function call for R's 
	\code{ts.plot} from the the \code{ts} package.
	\cr
	
	\bold{Histogram and Density Plots:}
	\cr\cr
	\code{histPlot} and \code{densityPlot} show (return) distributions in form 
	of a  histogram and density plots. The first is a synonyme function call 
	for R's histogram plot, calling the function \code{hist}. The outlook 
	of the plot is more SPlus like. The second creates a density Plot 
	with underlying kernel density estimation. It is a function call to  
	R's \code{density} function.
	\cr
 	
	\bold{Three Dimensional Plots:}
	\cr\cr
	\code{circlesPlot} and \code{perspPlot}, see also \code{contour},
	are functions to plot 3 dimensional data sets. The first is
	simple scatterplot with points replaced with variable circles, 
	whose size indexes a third variable. The second aloows to create
	a perspective 3 dimensional plot. It is a function call to R's
	\code{persp} plot, but the parameters are setted to produce a
	more SPlis like outlook of the plot. \code{contour} is the call
	to R's contour plot from the \code{base} package.
	\cr

	\bold{Plot Utilities:}
	\cr\cr
	\code{characterTable}, \code{plotcharacterTable} and \code{colorTable}
    are three helpful utilities for using characters and colors in plots.
	The first function displays a table of numerical equivalents to Latin 
	characters, the second displays a table of plot characters, i.e. 
	the symbols used in plots, and the third displays a table with the
	codes of the default plot colors.
	
}


\author{
 
  	Gordon Smyth for the circlesPlot, \cr
	Pierre Joyet for the characterTable, and \cr
	Diethelm Wuertz for this \R-port.
	
}


\seealso{
  
	\code{\link{plot}},
	\code{\link{persp}},  
  	\code{\link{contour}},
  	\code{\link{par}}.
  	
}


\examples{
## tsPlot -
   xmpBasics("\nStart: European Stock Markets > ")
   # Show multiple plot:
   par(mfrow=c(1, 1))
   data(EuStockMarkets)
   tsPlot(EuStockMarkets, gpars = list(col = c(2:4, 6)), labels = FALSE)
   title(main = "European Stock Markets")
   
   
## histPlot -
   xmpBasics("\nNext: Histogram Plot of Normal Random Numbers > ")
   histPlot(x = rnorm(1000), main = "Histogram Plot")
   
## densityPlot -
   xmpBasics("\nNext: Density Plot of Normal Random Numbers > ")
   densityPlot(x = rnorm(1000), main = "Density Plot")
   
## circlesPlot -
   xmpBasics("\nNext: 3D Circles Plot of Normal Random Numbers > ")
   circlesPlot(x = rnorm(50), y = rnorm(50), size = abs(rnorm(50)),
   	 main = "Circles Plot")

## perspPlot -
   xmpBasics("\nNext: Perspective Plot > ")
   par(mfrow = c(1, 1), ps = 11)
   x = y = seq(-10, 10, length=51)
   f = function(x, y) { r = sqrt(x^2+y^2); 10 * sin(r)/r }
   z = outer(x, y, f)	
   perspPlot(x, y, z)
   title(main = "Perspective Plot", line = -3)
   
## characterTable - 
   xmpBasics("\nNext: Print the Copyright Sign > ")
   cat("\251 \n")

## characterTable - 
   xmpBasics("\nNext: Display Character Table for Symbol Font > ")
   characterTable(5)
   
## colorTable - 
   xmpBasics("\nNext: Display Table of Plot Colors > ")
   colorTable()
   
## plotcharacter Table - 
   xmpBasics("\nNext: Display Table of Plot Characters > ")
   plotcharacterTable()
}


\keyword{hplot}


\eof
\name{ghypDistribution}

\alias{ghypDistribution}

\alias{dhyp}
\alias{phyp}
\alias{qhyp}
\alias{rhyp}

\alias{dnig}
\alias{pnig}
\alias{qnig}
\alias{rnig}

\title{Generalized Hyperbolic Distribution}


\description{
	
	A collection of functions to compute density, distribution function, 
	quantile function and to generate random variates for two special 
	cases of the generalized hyperbolic distribution: the hperbolic 
	distribution and the normal inverse Gaussian distribution. 
	\cr
	
	The functions are:
	
	\tabular{rll}{
		1	\tab  	\code{[dpqr]hyp} 	
			\tab  	The hyperbolic distribution, \cr
		2	\tab  	\code{[dpqr]nig} 	
			\tab  	The normal inverse Gaussian distribution.}
}


\usage{
dhyp(x, alpha , beta , delta , mu = 0)
phyp(q, alpha , beta , delta , mu = 0, ...)
qhyp(p, alpha , beta , delta , mu = 0)
rhyp(n, alpha , beta , delta , mu = 0)

dnig(x, alpha, beta, delta, mu = 0)
pnig(q, alpha, beta, delta, mu = 0)
qnig(p, alpha, beta, delta, mu = 0)
rnig(n, alpha, beta, delta, mu = 0)
}


\arguments{

  	\item{alpha, beta, delta, mu}{
		shape parameter \code{alpha};
		skewness parameter \code{beta}, \code{abs(beta)} is in the 
		range (0,alpha);
		scale parameter \code{delta}, \code{delta} must be zero or 
		positive; and
		location parameter \code{mu}, by default 0.
		}
	\item{n}{
		number of observations.
		} 
	\item{p}{
		a numeric vector of probabilities.
		}
	\item{x, q}{
		a numeric vector of quantiles.
		}
	\item{\dots}{
		arguments to be passed to the function \code{integrate}.
		}
	
}


\value{

	All values are numeric vectors:
	\code{d*} returns the density,
	\code{p*} returns the distribution function,
	\code{q*} returns the quantile function, and
	\code{r*} generates random deviates.
	
}

\details{
  
	\bold{Hyperbolic Distibution:}
	\cr\cr
	The generator \code{rhyperb} is based on the HYP algorithm given 
	by Atkinson (1982).
    \cr
    
    \bold{Normal Inverse Gaussian Distribution:}
    \cr\cr
    The random deviates are calculated with the method described by 
    Raible (2000).
    
}


\examples{
## hyp -
   xmpBasics("\nStart: Hyperbolic Distribution > ")
   par(mfcol = c(3, 2), cex = 0.5)
   set.seed(1953)
   r = rhyp(1000, alpha = 1, beta = 0.3, delta = 1)
   plot(r, type = "l", col = "steelblue4",
   	 main = "hyp: alpha =1 beta=0.3 delta=1")
   # Plot empirical density and compare with true density:
   hist(r, n = 25, probability = TRUE, border = "white", col = "steelblue4") 
   x = seq(-10, 50, 0.2)
   lines(x, dhyp(x, alpha = 1, beta = 0.3, delta = 1))
   # Plot df and compare with true df:
   plot(sort(r), (1:1000/1000), main = "Probability", col = "steelblue4")
   lines(x, phyp(x, alpha = 1, beta = 0.3, delta = 1))
   # Compute quantiles:
   qhyp(phyp(seq(-5, 7, 1), alpha = 1, beta = 0.3, delta = 1), 
     alpha = 1, beta = 0.3, delta = 1) 
 
     
## nig -
   xmpBasics("\nNext: Normal Inverse Gaussian Distribution > ")
   set.seed(1953)
   r = rnig(5000, alpha = 1, beta = 0.3, delta = 1)
   plot(r, type = "l", col = "steelblue4",
     main = "nig: alpha=1 beta=0.3 delta=1")
   # Plot empirical density and compare with true density:
   hist(r, n = 25, probability = TRUE, border = "white", col = "steelblue4")
   x = seq(-10, 10, 0.1)
   lines(x, dnig(x, alpha = 1, beta = 0.3, delta = 1))
   # Plot df and compare with true df:
   plot(sort(r), (1:5000/5000), main = "Probability", col = "steelblue4")
   lines(x, pnig(x, alpha = 1, beta = 0.3, delta = 1))
   # Compute Quantiles:
   qnig(pnig(seq(-5, 7, 1), alpha = 1, beta = 0.3, delta = 1), 
     alpha = 1, beta = 0.3, delta = 1) 
}


\author{

	David Scott for the HYP Generator from R's "HyperbolicDist" package, \cr
	Diethelm Wuertz for this \R-port.
	
}


\references{
Atkinson, A.C. (1982); 
	\emph{The simulation of generalized inverse Gaussian and hyperbolic 
	random variables},
	SIAM J. Sci. Stat. Comput. 3, 502-515. 

Barndorff-Nielsen O. (1977);
	\emph{Exponentially decreasing distributions for the logarithm of 
	particle size}, 
	Proc. Roy. Soc. Lond., A353, 401-419. 

Barndorff-Nielsen O., Blaesild, P. (1983); 
	\emph{Hyperbolic distributions. In Encyclopedia of Statistical 
	Sciences}, 
	Eds., Johnson N.L., Kotz S. and Read C.B., 
	Vol. 3, pp. 700-707. New York: Wiley. 

Raible S. (2000);
	\emph{Levy Processes in Finance: Theory, Numerics and Empirical Facts},
	PhD Thesis, University of Freiburg, Germany, 161 pages.
}


\seealso{
  
	\code{\link{dstable}},
  	\code{\link{dsymstb}}.
  	
}


\keyword{distribution}


\eof
\name{stableDistribution}

\alias{stableDistribution}

\alias{dsymstb}
\alias{psymstb}
\alias{qsymstb}
\alias{rsymstb}

\alias{dstable}
\alias{pstable}
\alias{qstable}
\alias{rstable}

\title{Stable Distribution Function}


\description{
	
	A collection of functions to Compute density, distribution function, 
	quantile function and to generate random variates from the stable 
	distribution. Two different algorithms are used for the symmetric 
	and skewed distribution.
	\cr
	
	The functions are:
	
	\tabular{rll}{
		1	\tab  	\code{[dpqr]symstb} 	
			\tab  	The symmetric stable distribution, \cr
    	2	\tab	\code{[dpqr]stable} 	
    		\tab  	The skewed stable distribution using parametrizition 0.}

}


\usage{
dsymstb(x, alpha)
psymstb(q, alpha)
qsymstb(p, alpha)
rsymstb(n, alpha)

dstable(x, alpha, beta, gamma=1, delta=0, pm = 0)
pstable(q, alpha, beta, gamma=1, delta=0, pm = 0)
qstable(p, alpha, beta, gamma=1, delta=0, pm = 0)
rstable(n, alpha, beta, gamma=1, delta=0, pm = 0)
}


\arguments{

  	\item{alpha, beta, gamma, delta}{
		value of the index parameter \code{alpha} with \code{alpha = (0,2]};
		skewness parameter \code{beta}, in the range [-1, 1];
		scale parameter \code{gamma}; and
		shift parameter \code{delta}.
		}
	\item{n}{
		number of observations, an integer value.
		} 
	\item{p}{
		a numeric vector of probabilities.
		}
  	\item{pm}{
		parameterization, at the moment only the 0-th 
		parameterization is supported.
		}
    \item{x, q}{
		a numeric vector of quantiles.
		}
	
}


\value{

	All values are numeric vectors: 
	\code{d*} returns the density, 
	\code{p*} returns the distribution function, 
	\code{q*} returns the quantile function, and
	\code{r*} generates random deviates.
	
}


\details{

	\bold{Symmetric Stable Distribution:}
	\cr\cr
	For the density and probability the approach of McCulloch is 
	implemented. Note, that McCulloch's approach has a density 
	precision of 0.000066 and a distribution precision of 0.000022 
	for \code{alpha} in the  range [0.84, 2.00]. 
	Quantiles are evaluated from a root finding process via the
	probability function. Thus, this leads to nonnegligible 
	errors for small quantiles, since the quantile evaluation 
	depends on the quality of the probability function.To achieve 
	higher precisions use the function \code{stable} with argument 
	\code{beta=0}. \cr
	For generation of random deviates the results of Chambers, 
	Mallows, and Stuck are used.
	\cr
	
	\bold{Skew Stable Distribution:}
	\cr\cr
	The function uses the approach of J.P. Nolan for general 
 	stable distributions. Nolan derived expressions in form of 
	integrals based on the charcteristic function for standardized 
	stable random variables. These integrals are numerically 
	evaluated using R's function \code{integrate}. 
	\cr
	"S0" parameterization: based on the (M) representation
   	of Zolotarev for an alpha stable distribution with skewness
   	beta. Unlike the Zolotarev (M) parameterization, gamma and 
 	delta are straightforward scale and shift parameters. This
   	representation is continuous in all 4 parameters, and gives 
   	an intuitive meaning to gamma and delta that is lacking in 
  	other parameterizations.} 
  	\cr
	"S" or "S1" parameterization: the parameterization used 
	by Samorodnitsky and Taqqu in the book Stable Non-Gaussian 
	Random Processes. It is a slight modification of Zolotarev's 
	(A) parameterization.} 
	\cr
	"S*" or "S2" parameterization: a modification of the S0 
	parameterization which is defined so that (i) the scale gamma 
	agrees with the Gaussian scale (standard dev.) when alpha=2 
	and the Cauchy scale when alpha=1, (ii) the mode is exactly at 
	delta.} 
	\cr
	"S3" parameterization: an internal parameterization.
   	The scale is the same as the S2 parameterization, the shift 
	is -beta*g(alpha), where g(alpha) is defined in the paper 
	below.}
}

\notes{
	
	Note, that up to now for the stable distribution, only 
	parameterization 0 is implemented!
	
}


\examples{	
## rsymstb -
   xmpBasics("\nStart: Symmetric Stable Distribuion:  > ")
   par(mfcol = c(3, 2), cex = 0.5)
   set.seed(1953)
   r = rsymstb(n = 1000, alpha = 1.85)
   plot(r, type = "l", main = "symstb: alpha = 1.85")
   # Plot empirical density and compare with true density:
   hist(r, n = 25, probability = TRUE, border = "white", col = "steelblue4")
   x = seq(-10, 10, 0.1)
   lines(x, dsymstb(x = x, alpha = 1.85))
   # Plot df and compare with true df:
   plot(sort(r), (1:1000/1000), main = "Probability", col = "steelblue4")
   lines(x, psymstb(x, alpha = 1.85))
   # Compute quantiles:
   qsymstb(psymstb(q = seq(-10, 10, 1), alpha = 1.85), alpha = 1.85)
   
## stable - 
   set.seed(1953)
   r = rstable(n = 1000, alpha = 1.85, beta = 0.3)
   plot(r, type = "l", main = "stable: alpha = 1,85 beta = 0.3")
   # Plot empirical density and compare with true density:
   hist(r, n = 25, probability = TRUE, border = "white", col = "steelblue4")
   x = seq(-10, 10, 0.1)
   lines(x, dstable(x = x, alpha = 1.85, beta = 0.3))
   # Plot df and compare with true df:
   plot(sort(r), (1:1000/1000), main = "Probability", col = "steelblue4")
   lines(x, pstable(q = x, alpha = 1.85, beta = 0.3))
   # Compute quantiles:
   qstable(pstable(seq(-10, 10, 1), alpha = 1.85, beta = 0.3), 
     alpha = 1.85, beta = 0.3)
}


\author{

	McCulloch for the Fortran program, and \cr
	Diethelm Wuertz for this \R-port.

}


\references{
Chambers J.M., Mallows, C.L. and Stuck, B.W. (1976);
    \emph{A Method for Simulating Stable Random Variables},
    J. Amer. Statist. Assoc. 71, 340--344.

Nolan J.P. (1999);
    \emph{Stable Distributions},
    Preprint, University Washington DC, 30 pages.
    
Nolan J.P. (1999);
    \emph{Numerical Calculation of Stable Densities and Distribution
    Functions},
    Preprint, University Washington DC, 16 pages.

Samoridnitsky G., Taqqu M.S. (1994);
	\emph{Stable Non-Gaussian Random Processes, Stochastic Models
	with Infinite Variance},
	Chapman and Hall, New York, 632 pages.

Weron, A., Weron R. (1999);
	\emph{Computer Simulation of Levy alpha-Stable Variables and
	Processes},
	Preprint Technical Univeristy of Wroclaw, 13 pages.
}

\seealso{
  
	\code{\link{dnig}},
  	\code{\link{dhyp}}.
  	
}


\keyword{distribution}


\eof
\name{distributionFits}

\alias{distributionFits}

\alias{tFit}
\alias{hypFit}
\alias{nigFit}

\alias{hypStats}

\title{Parameter Fit of a Distribution}


\description{

	A collection of maximum likelihood estimators to fit the 
	parameters of a distribution and to compute basic statistical
	properties. Included are estimators for the Student-t, the 
	hyperbolic and the normal inverse Gaussian distributions. 
	\cr

	The functions are:
	
	\tabular{rll}{
		1 	\tab 	\code{tFit}   	
			\tab 	MLE parameter fit for a Student t-distribution, \cr
		2 	\tab	\code{hypFit} 	
			\tab 	MLE parameter fit for a hyperbolic distribution, \cr
		3 	\tab	\code{hypStats}	
			\tab 	Computes Mean and Variance for a hyperbolic dist, \cr
		4 	\tab 	\code{nigFit} 	
			\tab 	MLE parameter fit for a normal inverse Gaussian distribution. }

}


\usage{
tFit(x, df, doplot = TRUE, 
	span = seq(from = -10, to = 10, by = 0.1), \dots)
hypFit(x, alpha = 1, beta = 0, delta = 1, mu = 0, doplot = TRUE, 
	span = seq(from = -10, to = 10, by = 0.1), \dots)
nigFit(x, alpha = 1, beta = 0, delta = 1, mu = 0, doplot = TRUE, 
	span = seq(from = -10, to = 10, by = 0.1), \dots)
	
hypStats(alpha = 1, beta = 0, delta = 1, mu = 0)
}


\arguments{
  
	\item{alpha, beta, delta, mu}{[hypFit][nigFit][hypStats] -
		shape parameter \code{alpha}; 
		skewness parameter \code{beta} with \code{0 < |beta| < alpha};
		scale parameter \code{delta} with \code{delta <= 0}; 
		location parameter \code{mu}.
		}
	\item{df}{[tFit] -
		the number of degrees of freedom for the Student distribution, 
		\code{df > 2}, maybe non-integer.
		}
	\item{doplot}{
		a logical. Should a plot be displayed?
		}
	\item{span}{
		x-coordinates for the plot, by default 201 values 
		ranging between -10 and +10.
		}
	\item{x}{
		a numeric vector.
		}
	\item{\dots}{
		parameters parsed to the function \code{density}.
		}

}


\value{
  
  	The functions \code{*Fit} return a list with the following components:
  
  	\item{estimate}{
		the point at which the maximum value of the log liklihood 
		function is obtained.
		}
  	\item{objective}{
		the value of the estimated maximum, i.e. the value of the
		log liklihood function.
		}
  	\item{message}{
		an integer indicating why the optimization process terminated.
		}
  	\item{code}{
		an integer indicating why the optimization process terminated.\cr
		1: relative gradient is close to zero, current iterate is probably 
			solution; \cr
		2: successive iterates within tolerance, current iterate is probably 
			solution; \cr
		3: last global step failed to locate a point lower than \code{estimate}. 
			Either \code{estimate} is an approximate local minimum of the 
			function or \code{steptol} is too small; \cr
 		4: iteration limit exceeded; \cr
 		5: maximum step size \code{stepmax} exceeded five consecutive times. 
 			Either the function is unbounded below, becomes asymptotic to a 
 			finite value from above in some direction or \code{stepmax} 
			is too small.
			}
  	\item{gradient}{
		the gradient at the estimated maximum.
		}
  	\item{steps}{
		number of function calls.
		}
	
  	The function \code{hypStats} returns a list with two elements: the 
  	mean, \code{mean}, and the variance, \code{var}.
  
}


\details{

	The function \code{\link{nlm}} is used to minimize the "negative" maximum 
	log-likelihood function. \code{nlm} carries out a minimization using 
	a Newton-type algorithm.
	
}


\examples{
## tFit -
   xmpBasics("\nStart: MLE Fit to Student's t Density > ")
   par(mfrow = c(2,2), cex = 0.7, err = -1)
   options(warn = -1)
   # Simulated random variates t(4):
   s = rt(n = 10000, df = 4) 
   # Note, this may take some time.
   # Starting vector:
   df.startvalue = 2*var(s)/(var(s)-1)
   tFit(s, df.startvalue, doplot = TRUE)
   
## hypFit -
   xmpBasics("\nNext: MLE Fit to Hyperbolic Density > ")
   # Simulated random variates HYP(1, 0.3, 1, -1):
   s = rhyp(n = 1000, alpha = 1.5, beta = 0.3, delta = 0.5, mu = -1) 
   # Note, this may take some time.
   # Starting vector (1, 0, 1, mean(s)):
   hypFit(s, alpha = 1, beta = 0, delta = 1, mu = mean(s), 
     doplot = TRUE, width = 0.5)
   
## nigFit -
   xmpBasics("\nNext: MLE Fit to Normal Inverse Gaussian Density > ")
   # Simulated random variates HYP(1.5, 0.3, 0.5, -1.0):
   s = rnig(n = 10000, alpha = 1.5, beta = 0.3, delta = 0.5, mu = -1.0) 
   # Note, this may take some time.
   # Starting vector (1, 0, 1, mean(s)):
   nigFit(s, alpha = 1, beta = 0, delta = 1, mu = mean(s), doplot = TRUE)
}


\seealso{
  
	\code{\link{dt}},
  	\code{\link{dhyp}}, 
  	\code{\link{dnig}}, 
  	\code{\link{nlm}}.
  	
}


\author{

	Diethelm Wuertz for this \R-port.
	
}


\keyword{distribution}


\eof
\name{classicalTests}

\alias{classicalTests}

\alias{ansariTest}
\alias{bartlettTest}
\alias{corTest}
\alias{flignerTest}
\alias{ksTest}
\alias{moodTest}
\alias{runsTest}
\alias{shapiroTest}
\alias{varTest}

% from lmtest:

\alias{adTest}             
\alias{cvmTest}		
\alias{lillieTest} 
\alias{pearsonTest}    
\alias{sfTest} 				

\alias{dagoTest}              


\alias{gofnorm}

\title{Classical Statistical Tests}


\description{
	
	A collection of functions for conventional statistical tests. Most 
	tests are selected from R's \code{cTest} and \code{nortest} packages 
	which may be of interest for financial and economic applications. 
	\cr
	
	The functions are:

	\tabular{rll}{
	 	1	\tab 	\code{ansariTest} 	
	 		\tab 	Ansari--Bradley's test for differences in scale, \cr
     	2	\tab 	\code{bartlettTest} 	
     		\tab 	Bartlett's test for differences in variances, \cr
     	3	\tab 	\code{corTest} 		
     		\tab 	A test for association between paired samples, \cr
     	4	\tab 	\code{flignerTest} 	
     		\tab 	Fligner--Killeen's test for differences in variances, \cr
     	5	\tab 	\code{ksTest} 		
     		\tab 	One or two sample Kolmogorov-Smirnov tests, \cr
     	6	\tab 	\code{moodTest} 		
     		\tab 	Mood's test for differences in scale parameters, \cr
	 	7	\tab 	\code{shapiroTest} 	
	 		\tab 	Shapiro-Wilk's test for normality, \cr
     	8	\tab 	\code{varTest} 		
     		\tab 	F test for differences in variances, \cr  
     	9   \tab    \code{dagoTest}
     	    \tab    D'Agostino normality test, \cr
       10	\tab 	\code{runsTest} 		
     		\tab 	Runs test for detecting non-randomness, \cr
       11	\tab 	\code{gofnorm} 		
       		\tab 	Prints a report on 13 different tests of normality. }
       		
	The following tests are available from the \code{"nortest"} package: 
	
	\tabular{rll}{
	 	1	\tab 	\code{adTest} 	
	 		\tab 	Anderson--Darling normality test, \cr
     	2	\tab 	\code{cvmTest} 	
     		\tab 	Cramer--von Mises normality test, \cr
     	3	\tab 	\code{lillieTest} 		
     		\tab 	Lilliefors (Kolmogorov-Smirnov) normality test, \cr
     	4	\tab 	\code{pearsonTest} 	
     		\tab 	Pearson chi-square normality test, \cr
     	5	\tab 	\code{sfTest} 		
     		\tab 	Shapiro-Francia normality test. }		
     
}


\usage{
ansariTest(x, y, \dots)
bartlettTest(x, g, \dots)
corTest(x, y, alternative = <<see below>>, method = <<see below>>, \dots)
flignerTest(x, g, \dots)
ksTest(x, y, alternative = <<see below>>, \dots)
moodTest(x, y, alternative = <<see below>>, \dots)
shapiroTest(x)
varTest(x, y, alternative = <<see below>>, \dots)

adTest(x)            
cvmTest(x)		
lillieTest(x) 
pearsonTest(x, n.classes = <<see below>>, adjust = TRUE)    
sfTest(x) 	

dagoTest(x, method = c("omnibus", "skewness", "kurtosis"))

runsTest(x)

gofnorm(x, doprint = TRUE)
}


\arguments{
  
	\item{adjust} {
		[pearsonTest] - \cr
		a logical flag, if \code{TRUE}, the default, the p-value 
		is computed from a chi-square distribution with 
		\code{n.classes-3} degrees of freedom, otherwise from a 
		chi-square distribution with n.classes-1 degrees of freedom. 
		}
	\item{alternative}{
	    indicates the alternative hypothesis; must be one of the 
	    entries specified by the input vector \code{c("two.sided", 
	    "less", "greater")}.
	    }
	\item{doprint}{
	    if TRUE, an exhaustive report is printed.
	    }
	\item{g}{
	    a vector or factor object giving the group for the
	    corresponding elements of \code{x}. Ignored if \code{x} 
	    is a list.
	    }
	\item{method}{
		[corTest] - \cr
	    indicates the three different methods for the correlation
	    test; must be one of the entries specified by the input 
	    vector \code{c("pearson", "kendall", "spearman")}.
	    [dagoTest] - \cr
	    selects the kind of test to be performed, either the
		\code{"omnibus"} (by default), the \code{"skewness"} or 
		the \code{"kurtosis"} test. A character string.
	    }    
	\item{n.classes}{
		[pearsonTest] - \cr
		the number of classes. The default is due to Moore (1986):
		\code{n.classes = ceiling(2 * (n^(2/5)))}.
		}
	\item{x, y}{
		a numeric vector of data values.
		}
	\item{\dots}{
	    arguments passed to the underlying function from R's
	    \code{ctest} package. Consult the appropriate manual pages.
	    }
	   
}


\value{

	The tests return a list with class \code{"htest"} containing 
	the following components:

    \item{statistic}{
		the value of the test statistic.
		}
  	\item{p.value}{
		the p-value of the test.
		}
  	\item{alternative}{
		a character string describing the alternative
		hypothesis.
		}
  	\item{method}{
		a character string indicating what type of test was performed.
		}
  	\item{data.name}{
		a character string giving the name(s) of the data.
		}
		
}


\details{

	\bold{Report from gofnorm:}
	\cr\cr
	The function reports the following goodness-of-fit tests
	for normality:

	\tabular{rl}{
	 1  \tab   Omnibus Moments Test for Normality \cr
	 2  \tab   Geary's Test of Normality \cr
	 3  \tab   Studentized Range for Testing Normality \cr
	 4  \tab   D'Agostino's D-Statistic Test of Normality \cr
	 5  \tab   Kuiper V-Statistic Modified to Test Normality \cr
	 6  \tab   Watson U-Squared-Statistic Modified to Test Normality \cr
	 7  \tab   Durbin's Exact Test (Normal Distribution \cr
	 8  \tab   Anderson-Darling Statistic Modified to Test Normality \cr
	 9  \tab   Cramer-Von Mises W-Squared-Statistic to Test Normality \cr
	10  \tab   Kolmogorov-Smirnov D-Statistic to Test Normality \cr
	11  \tab   Kolmogorov-Smirnov D-Statistic (Lilliefors Critical Values) \cr
	12  \tab   Chi-Square Test of Normality (Equal Probability Classes) \cr
	13  \tab   Shapiro-Francia W-Test of Normality for Large Samples }
	
	The functions are implemented from the GRASS GIS software package
	an Open Source project avalaible under the GNU GPL license.

}


\references{
Anderson T.W., Darling D.A. (1954); 
	\emph{A Test of Goodness of Fit},
	JASA 49:765--69.
	
Conover, W. J. (1971);
	\emph{Practical nonparametric statistics},
	New York: John Wiley & Sons.

D'Agostino R.B., Pearson E.S. (1973); 
	\emph{Tests for Departure from Normality},
	Biometrika 60, 613--22.

D'Agostino R.B., Rosman B. (1974); 
	\emph{The Power of Geary's Test of Normality},
	Biometrika 61, 181--84.

Durbin J. (1961); 
	\emph{Some Methods of Constructing Exact Tests},
	Biometrika 48, 41--55. 

Durbin,J. (1973);
	\emph{Distribution Theory Based on the Sample Distribution Function},
	SIAM, Philadelphia.

Geary R.C. (1947); 
	\emph{Testing for Normality}; 
	Biometrika 36, 68--97.

Kotz S. (1973); 
	\emph{Normality versus Lognormality with Applications},
	Communications in Statistics 1, 113--32.

Lehmann E.L. (1986); 
	\emph{Testing Statistical Hypotheses}, 
	John Wiley and Sons, New York.

Linnet K. (1988); 
	\emph{Testing Normality of Transformed Data},
	Applied Statistics 32, 180--186. 
	
Moore, D.S. (1986);
 	\emph{Tests of the chi-squared type}, 
 	In: D'Agostino, R.B. and Stephens, M.A., eds., 
 	Goodness-of-Fit Techniques, Marcel Dekker, New York. 

Shapiro S.S., Francia R.S. (1972); 
	\emph{An Approximate Analysis of Variance Test for Normality},
	JASA 67, 215--216.

Shapiro S.S., Wilk M.B., Chen V. (1968); 
	\emph{A Comparative Study of Various Tests for Normality},
	JASA 63, 1343--72.

Thode H.C. (2002);
	\emph{Testing for Normality}, 
	Marcel Dekker, New York. 

Weiss, M.S. (1978); 
	\emph{Modification of the Kolmogorov-Smirnov 
		Statistic for Use with Correlated Data}, 
	JASA 73, 872--75.
}


\examples{
## ansariTest - moodTest - varTest -
   xmpBasics("\nStart: Ansari/Mood/Var Test > ")
   # Differences in scale / variances:
   data(nyseres)
   x = nyseres[4001:5000, 1]
   y = nyseres[6001:7000, 1]
   p = c(
   	 ansariTest(x, y)$p.value,
	 moodTest(x, y)$p.value,
   	 varTest(x, y)$p.value)
   test = c("ansari", "mood", "var") 
   data.frame(test, p)
   
## ansariTest - moodTest - varTest -
   xmpBasics("\nNext: Ansari/Mood/Var Test > ")
   # Differences in scale / variances:
   x = rnorm(1000)
   y = rnorm(1000)
   p = c(
   	 ansariTest(x, y)$p.value,
	 moodTest(x, y)$p.value,
   	 varTest(x, y)$p.value)
   test = c("ansari", "mood", "var") 
   data.frame(test, p)
   
## gofnorm -
   xmpBasics("\nNext: Goodness-of-Fit Test for Normality > ")  
   x = nyseres[1:1000, 1]
   # Standardize the data:
   x = (x-mean(x))/sqrt(var(x))
   # Test:
   r = gofnorm(x, doprint = TRUE)
   
## ksTest -
   # unique: remove ties:
   xmpBasics("\nNext: Kolmogorov-Smirnov Goodness-of-Fit Test > ")
   nyseres = unique(nyseres[, 1])
   ksTest(nyseres, "pnorm")
   # Do x and y come from the same distribution?
   x = nyseres[1:(length(nyseres)/2)]
   y = nyseres[(length(nyseres)/2+1):length(nyseres)]
   ksTest(x, y)
   # Does x come from an alpha stable distribution?
   alpha = scalinglawPlot(nyseres, doplot = FALSE)$exponent
   ksTest(x = nyseres, y = "psymstb", alpha, alternative = "gr")
   
## runsTest -
   xmpBasics("\nNext: Runs Test > ")
   runsTest(nyseres)
   runsTest(rnorm(length(nyseres)))
}


\author{

	R-core team for the tests from \R's ctest package,\cr
	Adrian Trapletti for the runs test from \R's tseries package,\cr
	Juergen Gross for the normal tests from \R's nortest package,\cr
	James Filliben for the Fortran program producing the runs report,\cr
	Paul Johnson for the Fortran program producing the gofnorm report, \cr
	Diethelm Wuertz for this R-port. \cr
	
}


\keyword{htest}


\eof
\name{stylizedFacts}

\alias{stylizedFacts}

\alias{logpdfPlot}
\alias{qqgaussPlot}
\alias{scalinglawPlot}
\alias{acfPlot}
\alias{pacfPlot}
\alias{ccfPlot}
\alias{lmacfPlot}
\alias{teffectPlot}

\title{Stylized Facts}


\description{

	A collection of functions to plot several stylized facts 
	of financial and economic time series. This includes fat tails,
	autocorrelations, crosscorrelations, long memory behavior, and the
	Taylor effect.
	\cr

	The functions are:
	
	\tabular{rll}{
		1	\tab	\code{logpdfPlot} 	 
			\tab  	logarithmic density plots, \cr
		2	\tab	\code{qqgaussPlot} 	 
			\tab  	Gaussian quantile quantile plot, \cr
		3	\tab	\code{scalinglawPlot} 
			\tab  	scaling behavior plot, \cr
		4	\tab	\code{acfPlot} 		 
			\tab  	autocorrelation function plot, \cr
		5	\tab	\code{pacfPlot} 		 
			\tab  	partial autocorrelation function plot, \cr
		6	\tab	\code{ccfPlot} 		 
			\tab  	cross correlation function plot, \cr
		7	\tab	\code{lmacfPlot} 	 
			\tab  	long memory autocorrelation function plot, \cr
		8	\tab	\code{teffectPlot} 	 
			\tab  	Taylor effect plot.}
	
}


\usage{
logpdfPlot(x, n = 50, doplot = TRUE, type = c("lin-log", "log-log"), \dots)
qqgaussPlot(x, span = 5, \dots)
scalinglawPlot(x, span = ceiling(log(length(x)/252)/log(2)), doplot=TRUE, \dots)
acfPlot(x, \dots)
pacfPlot(x, \dots)
ccfPlot(x, y, \dots)
lmacfPlot(x, lag.max = 50, ci = 0.95, main = "ACF", doprint = TRUE)
teffectPlot(x, deltas = seq(from = 0.2, to = 3, by = 0.2), lag.max = 10, 
	ymax = NA, standardize = TRUE)
}


\arguments{

  	\item{ci}{
		confidence interval, by default 95 percent, i.e. 0.95.
		}
  	\item{deltas}{
		the exponents, a numeric vector, by default ranging 
		from 0.2 to 3.0 in steps of 0.2.
		}
  	\item{doplot}{
		a logical. Should a plot be displayed?
		}
  	\item{doprint}{
		a logical, should the results be printed?
		}
  	\item{lag.max}{
		maximum lag for which the autocorrelation should be 
		calculated, an integer.
		}
  	\item{main}{
		a character string, the title of the plot.
		}
	\item{n}{
  		an integer, the number of break and count points.
  		}
  	\item{type}{
		a character, either \code{e} for "exceedences", \code{d} 
		for "distances", or by default \code{b} for "both", 
		selecting which plot should be displayed.
		}
	\item{span}{
  		an integer value, determines for the \code{qqgaussPlot} the 
  		plot range, by default 5, and for the \code{scalingPlot} a
  		reasonable number of of points for the scaling range, by
  		default daily data with 252 business days per year are
  		assumed.
  		}
  	\item{standardize}{
		a logical. Should the vector \code{x} be standardized?
		}
	\item{x, y}{
  		a numeric vector; for \code{acfPlot}, \code{pacfPlot} and 
  		\code{ccfPlot} a numeric vector or matrix or a univariate or 
  		multivariate (not \code{ccf}) time series object.
  		}
  	\item{ymax}{
		maximum y-axis value on plot, is.na(ymax) TRUE the 
		value is selected automatically.
		}
  	\item{\dots}{
    	for \code{tsPlot} one or more univariate or multivariate time 
    	series, else other arguments to be passed.
    	}

}


\value{
	
	\code{logpdfPlot}
	\cr
	returns a list with the following components: \code{breaks}, 
	histogram mid-point breaks; \code{counts}, histogram counts;
    \code{fbreaks}, fitted Gaussian breaks; \code{fcounts}, fitted 
    Gaussian counts.
    \cr
    
    \code{qqgaussPlot}
    \cr
    returns a Gaussian Quantile-Quantile Plot.
    \cr
      
    \code{scalingPlot}
    \cr
    returns a list with the following components: \code{exponent},
	the scaling exponent, a numeric value; \code{fit}, a list with 
	the coefficients returned by \code{lsfit}, i.e. \code{intercept} 
	and \code{X}.
	\cr
	
	\code{acfPlot}, \code{pacfplot}, \code{ccfPlot}
	\cr
	return an object of class \code{"acf"}, see \code{\link{acf}}.
	\cr

	\code{lmacfPlot}
	\cr
	returns a  list with the following elements: \code{fit}, a list 
	by itself with elements \code{Intercept} and slope \code{X},
    \code{hurst}, the Hurst exponent, both are numeric values.
    \cr
	
	\code{teffectPlot}
	\cr
	returns a numeric matrix of order \code{deltas} by \code{max.lag} 
	with the values of the autocorrelations.
	
}

\details{

	
	\bold{Tail Behavior:}
	\cr\cr
	\code{logpdfPlot} and \code{qqgaussPlot} are two simple functions
	which allow a quick view on the tails of a distribution.
	The first creates a logarithmic or 
	double-logarithmic density plot and returns breaks and counts.
	For the double logarithmic plot, the negative side of the distribution 
	is reflected onto the positive axis.\cr
	The second creates a Gaussian Quantile-Quantile plot.
	\cr
	
	\bold{Scaling Behavior:}
	\cr\cr
	The function \code{scalingPlot} plots the scaling law of financial 
	time series under aggregation and returns an estimate for the scaling 
	exponent. The scaling behavior is a very striking effect of the 
	foreign exchange market and also other markets expressing a regular
	structure for the volatility. Considering the average absolute
	return over individual data periods one finds a scaling power law
	which relates the mean volatility over given time intervals
	to the size of these intervals. The power law is in many cases 
	valid over several orders of magnitude in time. Its exponent  
	usually deviates significantly from a Gaussian random walk model 
	which implies 1/2. 
	\cr
	
	\bold{Autocorrelation Functions:}
	\cr\cr
	The functions \code{acfPlot}, \code{pacfPlot}, and \code{ccfPlot}
	plots and estimate autocorrelation, ACF, partial autocorrelation, 
	PACF, and cross-covariance and cross-correlation functions, CCF. 
	The functions allow to get a first view on correlations in and 
	between time series. The functions are synonyme function 
	calls for R's \code{acf}, \code{pacf}, and \code{ccf} from the 
	the \code{ts} package.
	\cr
	
	\bold{Long Memory Autocorrelation Function:}
	\cr\cr
	The function \code{lmacfPlot} plots and estimates the 
	long memory autocorrelation function and computes from the 
	plot the  Hurst exponent of a time series. The volatility of  
	financial time series exhibits (in contrast to
  	the logarithmic returns) in almost every financial market a slow
  	ecaying autocorrelation function, ACF. We talk of a long memory 
  	if the decay in the ACF is slower than exponential, i.e. the 
  	correlation function decreases algebraically with increasing 
  	(integer) lag. 
	Thus it makes sense to investigate the decay on a double-logarithmic 
  	scale and to estimate the decay exponent. The function
  	\code{lmacf} calculates and plots the autocorrelation function of 
  	the vector \code{x}. If the time series exhibits long memory 
  	behaviour, it can easily be seen as a stright line in the plot. 
  	This double-logarithmic plot is displayed and a linear regression 
  	fit is done from which the intercept and slope ar calculated. 
  	From the slope the Hurst exponent is derived.
  	\cr
  		
	\bold{Taylor Effect:}
	\cr\cr
	The "Taylor Effect" describes the fact that absolute returns of
	speculative assets have significant serial correlation over long
	lags. Even more, autocorrelations of absolute returns are
	typically greater than those of squared returns. From these 
	observations the Taylor effect states, that that the autocorrelations
	of absolute returns to the the power of \code{delta}, 
	\code{abs(x-mean(x))^delta} reach their maximum at \code{delta=1}.
	The function \code{teffect} explores this behaviour. A plot is
	created which shows for each lag (from 1 to \code{max.lag}) the 
	autocorrelations as a function of the exponent \code{delta}. 
	In the case that the above formulated hypothesis is supported,
	all the curves should peak at the same value around \code{delta=1}.
	
}


\examples{
## logpdfPlot -
   xmpBasics("\nStart: log PDF Plot > ")
   # Plot the log-returns of the NYSE Composite Index
   # and compare with the Gaussian Distribution:  
   par(mfrow = c(2, 2))
   data(nyseres)
   # Extract from data.frame:
   x = nyseres[, 1]
   logpdfPlot(x, main = "log PDF Plot")
   # loglogpdfPlot -
   # Plot the log-returns of the NYSE Composite Index
   # and compare with the Gaussian Distribution:
   logpdfPlot(x, type = "log-log", main = "log-log PDF Plot")
   
## qqgaussPlot -
   xmpBasics("\nNext: QQ Normal Plot > ")
   # Create a Gaussian Quantile-Quantile plot
   # for the NYSE Composite Index log-returns:
   qqgaussPlot(x)
   
## scalinglawPlot -
   xmpBasics("\nNext: Scaling Law  Plot > ")
   # Investigate and Plot the Scaling Law
   # for the NYSE Composite Index log-returns:
   scalinglawPlot(x)
    
## acfPlot -
   xmpBasics("\nNext: Auto-Correlation Function Plot > ")
   data(EuStockMarkets)
   par(mfrow = c(2, 1))
   returns.ftse = diff(log(EuStockMarkets[,"FTSE"]))
   returns.dax = diff(log(EuStockMarkets[,"DAX"]))
   acfPlot(x = returns.ftse, main = "FTSE Autocorrelation")
   
## ccfPlot -
   xmpBasics("\nNext: Cross-Correlation Function Plot > ")
   ccfPlot(x = returns.ftse, y = returns.dax,
   	 main="FTSE - DAX Crosscorrelation")

## lmacfPlot -
   xmpBasics("\nNext: Long-Memory ACF Plot > ")
   # Estimate and plot the Long Memory ACF of the DAX volatilities
   # and evaluate the Hurst exponent of a time series:
   par(mfrow = c(2, 1))
   lmacfPlot(abs(returns.dax), main = "DAX")
   
## teffectPlot -
   xmpBasics("\nNext: Taylor Effect Plot > ")
   # Estimate and plot the Taylor Effect for the
   # log returns of the NYSE Compositie Index.
   teffectPlot(returns.dax)
   teffectPlot(returns.ftse)
}


\references{
Taylor S.J. (1986); 
	\emph{Modeling Financial Time Series},
	John Wiley and Sons, Chichester.

Ding Z., Granger C.W.J., Engle R.F. (1993); 
	\emph{A long memory proerty of stock market returns and a new model},
	Journal of Empirical Finance 1, 83.
	
}


\author{

	Diethelm Wuertz for this \R-port.
	
}


\keyword{hplot}


\eof
\name{timeDateClass}

\alias{timeDateClass}

\alias{rulesFinCenter}
\alias{listFinCenter}

\alias{timeDate}
\alias{timeDate-class}
\alias{timeCalendar}
\alias{timeSequence}
\alias{Sys.timeDate}

\alias{timeLastDayInMonth}
\alias{timeNdayOnOrAfter}
\alias{timeNdayOnOrBefore}
\alias{timeNthNdayInMonth}
\alias{timeLastNdayInMonth}

\alias{is.timeDate}
\alias{print.timeDate}
\alias{summary.timeDate}
\alias{format.timeDate}


\title{timeDate Class}


\description{
    
    A collection of functions for managing date and time around the
    globe for any financial center. The concept allows for dealing
    with time zones, day light saving time and holiday calendars
    independent of the date and time specifications of the operating 
    system implemented on your computer. This is an important issue
    especially for R running under Microsoft's Windows operating
    system.
    
    IMPORTANT: \cr
    The \code{timeDate} and \code{timeSeries} classes are so far
    tested only under MS Windows XP operating system. Note, that
    your time zone environment variable must be set to "GMT". The
    reason for this is, that the functions work internally with "GMT"
    POSIX date and time objects whereas the Daylight Saving Time is 
    added on top of this through the information in the Ical Calendar
    Library.
    \cr
    
    The functions are:

    \tabular{rll}{   
    		\tab
    		\tab	\cr
    		\tab
    		\tab	\bold{Financial Centers:} \cr
        1   \tab    \code{rulesFinCenter}   
            \tab    Returns DST rules for a financial center, \cr
        2   \tab    \code{listFinCenter}    
            \tab    Lists all supported financial centers. \cr  
    		\tab
    		\tab	\cr
    		\tab		
    		\tab	\bold{Generation of 'timeDate' Objects:} \cr   
        1   \tab    \code{timeDate}         
            \tab    S4: Creates 'timeDate' object from a character vector, \cr
        2   \tab    \code{timeCalendar}     
            \tab    S4: Creates 'timeDate' object from calendar atoms, \cr
        3   \tab    \code{timeSequence}         
            \tab    S4: Creates regularly spaced object of class 'timeDate', \cr
        4   \tab    \code{Sys.timeDate}         
            \tab    Returns system time as an object of class 'timeDate'. \cr           
    		\tab
    		\tab	\cr
    		\tab
    		\tab	\bold{Special Monthly 'timeDate' Sequences:} \cr                
		1   \tab    \code{timeLastDayInMonth}   
            \tab    Computes the last day in a given month and year, \cr
        2   \tab    \code{timeNdayOnOrAfter}        
            \tab    Computes date that is a "on-or-after" n-day, \cr  
        3   \tab    \code{timeNdayOnOrBefore}       
            \tab    Computes date that is a "on-or-before" n-day, \cr
        4   \tab    \code{timeNthNdayInMonth}       
            \tab    Computes n-th ocurrance of a n-day in year/month, \cr
        5   \tab    \code{timeLastNdayInMonth}      
            \tab    Computes the last n-day in year/month. \cr            
            \tab
    		\tab	\cr
    		\tab
    		\tab	\bold{Representation of 'timedate' Objects:} \cr                
       	1   \tab    \code{is.timeDate}      
            \tab    Checks if the object is of class 'timeDate', \cr
       	2   \tab    \code{print.timeDate}       
            \tab    Prints 'timeDate', 'FinCenter' and 'Data' Slot, \cr
        3   \tab    \code{summary.timeDate}         
            \tab    Summarizes details of a 'timeDate' object, \cr
        4   \tab    \code{format.timeDate}      
            \tab    Formats 'timeDate' as ISO conform character string.}
        
}


\usage{
rulesFinCenter(FinCenter = myFinCenter)
listFinCenter(pattern = "*")

timeDate(charvec, format = NULL, zone = "GMT", FinCenter = myFinCenter) 
timeCalendar(y = currentYear, m = 1:12, d = NULL, h = NULL, min = NULL, 
    s = NULL, FinCenter = myFinCenter)
timeSequence(from = "2004-01-01", to = format(Sys.time(), "\%Y-\%m-\%d"), by =
    "day", length.out = NULL, format = "", FinCenter = myFinCenter)
Sys.timeDate(FinCenter = myFinCenter) 

timeLastDayInMonth(charvec, format = "\%Y-\%m-\%d", FinCenter = "GMT")
timeNdayOnOrAfter(charvec, nday = 1, format = "\%Y-\%m-\%d", FinCenter = "GMT")
timeNdayOnOrBefore(charvec, nday = 1, format = "\%Y-\%m-\%d", FinCenter = "GMT")
timeNthNdayInMonth(charvec, nday = 1, nth = 1, format = "\%Y-\%m-\%d", 
	FinCenter = "GMT")
timeLastNdayInMonth(charvec, nday = 1, format = "\%Y-\%m-\%d", FinCenter = "GMT")

is.timeDate(object) 
\method{print}{timeDate}(x, \dots) 
\method{summary}{timeDate}(object, \dots)
\method{format}{timeDate}(x, \dots)
}


\arguments{
  
    \item{by}{
        a character string, containing one of "sec", "min",
        "hour", "day", "week", "month" or "year".
        This can optionally be preceded by an integer and a
        space, or followed by "s". 
        }
    \item{charvec}{
        a character vector of dates and times.
        }
    \item{FinCenter}{
        a character with the the location of the  
        financial center named as "continent/city". 
        }
    \item{format}{
        the format specification of the input character vector.
        }
    \item{from, to}{
        starting date, required, and end date, ptional. If supplied 
        \code{to} must be after \code{from}.
        }
    \item{h, min, s}{
        hours of the days (0-23), defaults are 0,
        minutes of the days (0-59), defaults are 0, and 
        seconds of the days (0-59), defaults are 0. 
        }
    \item{length.out}{
        length.out integer, optional. Desired length  
        of the sequence, if specified "to" will be ignored.
        }
    \item{nday}{
        an integer vector with entries ranging from 
        \code{0} (Sunday) to \code{6} (Saturday).
        }
    \item{nth}{
        an integer vector numbering the n-th occurence.
        }     
    \item{object}{
    	[is.timeData][summary] - \cr
    	an object of class \code{timeDate}.
    	}
    \item{pattern}{
        a pattern character string which can be recognized
        by the \code{grep} function. Wild cards are allowed.
        }
    \item{x}{
    	[format][print] - \cr
    	an object of class \code{timeDate}.
    	}
   	\item{y, m, d}{
        calendar years (e.g. 1997), defaults are 1960,
        calendar months (1-12), defaults are 1, and 
        calendar days (1-31), defaults are 1. 
        }
    \item{zone}{
        the time zone or financial center where the data were recorded.
        }   
    \item{\dots}{
        arguments passed to other methods.
        }
       
}


\value{

    \code{rulesFinCenter}\cr
    \code{listFinCenter}
    \cr
    the first function returns a printed list of DST rules, the second
    lists time zones available in the database.
    \cr
    
    \code{timedate}\cr
    \code{timeCalendar}\cr
    \code{timeSequence}
    \cr
    return a S4 object of class 'timeDate'.
    \cr
    
    \code{Sys.timeDate}
    \cr
    returns the system time as an object of class 'timeDate'.
    \cr
    
    \code{timeLastDayInMonth}\cr
    \code{timeNdayOnOrAfter}\cr
    \code{timeNdayOnOrBefore}\cr
    \code{timeNthNdayInMonth}\cr
    \code{timeLastNdayInMonth}
    \cr
    return \code{timeDate} objects on special dates. For the function 
    \code{timeLastDayInMonth} the last day in a given month and year 
    will be returned, for \code{timeNdayOnOrAfter} the date in the 
    specified month that is a n-day  on or after a given date, for 
    \code{timeNdayOnOrBefore} the date that is a n-day on or before a 
    given date, for \code{timeNthNdayInMonth} the \code{nth} ocurrance 
    of a \code{nday} (nth = 1,...,5) in \code{year}, \code{month}, and
    for {timeLastNdayInMonth} the last \code{nday} in \code{year},
    \code{month}. 
    \cr
    
    \code{is.timeDate}
    \cr
    returns \code{TRUE} or \code{FALSE} depending on whether its
    argument is of \code{timeDate} type or not.
    \cr
    
    \emph{Print method:}
    \cr
    prints the financial center and date and time vector for a 
    \code{timeDate} object.
    \cr
    
    \emph{Summary method:}
    \cr
    returns a summary report of the details of a \code{timeDate} 
    object. This includes the starting and end date, the number of 
    dates the format and financial center in use.
    \cr
    
    \emph{Format Method:}
    \cr
    returns an ISO conform formatted character string.
}


\details{

    For the management of chronological objects under R three concepts 
    are available: The first is the implementation of date and time in R's 
    \code{chron} package neglecting locals, time zones and day light saving 
    times. This approach is appropriate for economic time series. The second 
    approach, available in R's base package implements the POSIX standard 
    to date and time objects, named \code{"POSIXt"}. Unfortunately, the 
    representation of these objects is operating system dependent and 
    especially under MS Windows several problems appear in the management 
    of time zones and day light saving times. Here we present a solution
    to overcome these difficulties with POSIX objects and introduce a 
    new S4 class of 'timeDate' objects which allow for powerful methods 
    to represent dates and times in different financial centers around 
    the world. Many of the basic functionalities of these objects are in 
    common with S-Plus' \code{timeDate} objects and thus many of your 
    privately written functions for \code{FinMetrics} may also be used 
    within R's environment.

    A major difference is the time zone concept which is replaced by the
    "Financial Center" concept. The \code{FinCenter} character variable
    specifies where you are living and at which financial center you are
    working. With the variable \code{myFinCenter} you can overwrite the
    default setting with your personal settings.  
    With the specification of the \code{FinCenter} your system knows what
    rules rules for day light saving times should be applied, what is your
    holiday calendar, what are your interest rate conventions. (Not all
    specifications are already implemented.) Many other 
    aspects can be easily accessed when a financial center is named. So we 
    can distinguish between Frankfurt and Zurich, which both belong to the 
    same time zone, but differed in DST changes in the eighties and have
    different holiday calendars. Futhermore, since the underlying time 
    refers to "GMT" and DST rules and all other information is available 
    in local (ASCII) databases, we are sure, that R delivers with such a 
    date/time concept on every computer independent of the operating system 
    in use, identical results. 

    Another important feature of the \code{"timeDate"} concept used here is 
    the fact that we don't rely on American or European ways to write dates.
    We use consequently the ISO-8601 standard for date and time notations.
    \cr
    
    
    \bold{Financial Centers}
    \cr\cr
    There are two functions concerned with the financial centers. The 
    first, \code{rulesFinCenter}, lists the daylight saving rules for a 
    selected financial center, and the second, \code{listFinCenter}, 
    lists all centers available in the database. There is no dependency 
    on the POSIX implementation of your operating system because all 
    time zone and day light saving time information is stored locally 
    in ASCII files. It is important to say, that the \code{TZ} environment 
    variable must set to \code{"GMT"} in your system environment that 
    there are no conflicts with the POSIX time zone management.
       
    Through the definition of financial centers it becomes possible to 
    introduce in the future a specification structure for financial
    centers, which includes further information for a center like
    holiday calendars, currency and interest rate conventions or many
    others.
    \cr
    
    
    \bold{Generation of timeDate Objects}
    \cr\cr
    We have defined a 'timeDate' class which is in many aspects similar
    to the S-Plus class with the same name, but has also some important
    advantageous differeneces. The S4 class has four Slots, the \code{Data} 
    slot which holds date and time as 'POSIXlt' objects in the standard
    ISO-8601 format, the \code{Dim} slot which gives the dimension
    of the data object, the \code{format} specification slot and the
    \code{FinCenter} slot which holds the name of the financial center. 
    
    Three functions allow to cgenerate date/time objects: \code{timeDate} 
    from character vectors, \code{timeCalendar} from date and time atoms, 
    and \code{timeSequence} from a "from/to" or from a "from/length" sequence 
    specification. Note, time zone transformations are easily handled by
    by the \code{timeDate} functions which can also take \code{timeDate} 
    and \code{POSIXt} objects as inputs, while transforming them between 
    financial centers and/or time zones specified by the arguments \code{zone} 
    and \code{FinCenter}. Finally the function \code{Sys.timeDate} returns 
    current system time in form of a \code{timeDate} object.
    \cr
    
    
    \bold{Special Monthly timeDate Sequences}
    \cr\cr
    We have implemented five functions to generate special monthly 
    sequences. These are functions to compute the last day in a given 
    month and year, to compute the dates in a month that is a n-day on or 
    after a given date, to compute the dates in a month that is a n-day 
    on or before a specified date, to compute the n-th ocurrances of a 
    n-day for a specified year/month vectors, and finally to compute 
    the last n-day for a specified year/month value or vector. n-days
    are numbered from 0 to 6 where 0 correspond to the Sunday and 6 to 
    the Saturday.
    \cr
    
    
    \bold{Tests and Representation of timeDate Objects:}
    \cr\cr
    We have implemented four S3 methods to test and represent
    \code{timeDate} objects. The method \code{is.timeDate} checks if 
    a given object is of class \code{"timeDate"}. The print method 
    returns the date/time in square \code{"[]"} brackets to dsitinguish
    the output from other date and time objects. On top of the date and
    time output the name of the \code{FinCenter} is printed. The summary 
    method returns a printed report with information about the 
    \code{"timeDate"} object. Finally, the format methods allows to 
    transform objects into a ISO conform formatted character strings.

}


\notes{

    These functions were written for Rmetrics users using R and Rmetrics
    under Microsoft's Windows XP operating system where timze zones, 
    daylight saving times and holiday calendars are insuffeciently 
    supported. The functions are untested for other system environments, 
    but may be used.
    
    The usage of the Ical Library and the introduction of the FinCenter
    concept was originally develloped for R Version 1.5. The 
    \code{timeDate} and \code{timeSeries} objects were added for 
    R Version 1.8.1. Minor changes were made to adapt the functions 
    for R Version 1.9.1. As a consequence, newer concepts like the 
    \code{Date} objects were not yet considered and included in this 
    collection of date and time concepts.
    
    IT IS IMPORTANT THAT YOU SET YOUR ENVIRONMENT VARIABLE TZ TO 'GMT',
    OTHERWISE SOME OF THE 'TIMEDATE' FUNCTIONS WOULD NOT PROPERLY WORK! 
    
    Beside the examples given in the manual pages additional demo files
    are available with much more examples including also those from the 
    book of Zivot and Wang.

}


\references
{
Bateman R., (2000);
    \emph{Time Functionality in the Standard C Library},
    Novell AppNotes, September 2000 Issue, 73--85.

ISO-8601, (1988);
    \emph{Data Elements and Interchange Formats -
    Information Interchange, Representation of Dates and Time},
    International Organization for Standardization,
    Reference Number ISO 8601, 14 pages.

James D.A., Pregibon D. (1992),
    \emph{Chronological Objects for Data Analysis},
    Reprint.
    
Ripley B.D., Hornik K. (2001);
    \emph{Date-Time Classes},
    R-News, Vol. 1/2 June 2001, 8--12.
    
Zivot, E., Wang J. (2003);
	\emph{Modeling Financial Time Series with S-Plus},
	Springer, New-York.
}


\seealso
{
	We recommend to inspect the help pages for the POSIX time and date 
	class, \code{?Dates},  and the help pages from the contributed R packages
	\code{chron} and \code{date}.
}


\examples{
## c -
   xmpBasics("\nStart: Create Character Vectors > ") 
   dts = c("1989-09-28", "2001-01-15", "2004-08-30", "1990-02-09")
   tms = c(  "23:12:55",   "10:34:02",   "08:30:00",   "11:18:23")
   dts; tms
   
## timeDate -
   xmpBasics("\nNext: Construct timeDate Object from Character Vector > ") 
   timeDate(dts, format = "\%Y-\%m-\%d", FinCenter = "GMT" )
   timeDate(dts, format = "\%Y-\%m-\%d", FinCenter = "Europe/Zurich") 
   timeDate(paste(dts, tms), format = "\%Y-\%m-\%d \%H:\%M:\%S", 
     zone = "GMT", FinCenter = "GMT")
   timeDate(paste(dts, tms), format = "\%Y-\%m-\%d \%H:\%M:\%S", 
     zone = "Europe/Zurich", FinCenter = "Europe/Zurich")
   timeDate(paste(dts, tms), format = "\%Y-\%m-\%d \%H:\%M:\%S", 
     zone = "GMT", FinCenter = "Europe/Zurich") 
    
## timeCalendar - 
   xmpBasics("\nNext: Create a timeDate Object From Calendar Atoms > ")
   timeCalendar( m = c(9, 1, 8, 2), d = c(28, 15, 30, 9), 
     y = c(1989, 2001, 2004, 1990), FinCenter = "GMT") 
   timeCalendar(m = c(9, 1, 8, 2), d = c(28, 15, 30, 9), 
     y = c(1989, 2001, 2004, 1990), FinCenter = "Europe/Zurich")
   timeCalendar(h = c(9, 14), min = c(15, 23)) 
  
## timeSequence - 
   xmpBasics("\nNext: Create a Regularly Spaced timeDate Objects > ")
   timeSequence(from = "2004-03-12", to = "2004-04-11", 
        format = "\%Y-\%m-\%d", FinCenter = "GMT")  
   timeSequence(from = "2004-03-12", to = "2004-04-11", 
        format = "\%Y-\%m-\%d", FinCenter = "Europe/Zurich")
   
## timeDate - 
   xmpBasics("\nNext: Note, ISO and American Formats are Auto-Detected > ")
   timeDate("2004-12-11", FinCenter = "GMT")    
   timeDate("12/11/2004", FinCenter = "GMT")    
}


\author{

    Diethelm Wuertz for this R-port.
    
}


\keyword{chron}


\eof
\name{timeDateMethods}

\alias{timeDateMethods}

\alias{[.timeDate}
\alias{+.timeDate}
\alias{-.timeDate}
\alias{Ops.timeDate}
\alias{diff.timeDate}
\alias{difftimeDate}

\alias{c.timeDate}
\alias{rep.timeDate}

\alias{start.timeDate}
\alias{end.timeDate}

\alias{modify.timeDate}
\alias{rev.timeDate}

\alias{as.character.timeDate}
\alias{as.data.frame.timeDate}
\alias{as.POSIXct.timeDate}
\alias{julian.POSIXt}
\alias{julian.timeDate}
\alias{atoms.timeDate}
\alias{months.timeDate}


\title{timeDate Methods}


\description{
    
    A collection of methods for objects of class 'timeDate'. Included
    are S3 methods for mathematical operations and for transformations
    between different representations of date/time objects.
    \cr
    
    IMPORTANT: \cr
    The \code{timeDate} and \code{timeSeries} classes are so far
    tested only under MS Windows XP operating system. Note, that
    your time zone environment variable must be set to "GMT". The
    reason for this is, that the functions work internally with "GMT"
    POSIX date and time objects whereas the Daylight Saving Time is 
    added on top of this through the information in the Ical Calendar
    Library.
    \cr
    
    The methods are:

    \tabular{rll}{   
    		\tab
    		\tab	\cr
    		\tab
    		\tab	\bold{Math Operations with 'timeDate' Objects:} \cr
         1  \tab    \code{[.timeDate}   
            \tab    Extracts, replaces subsets from 'timeDate' objects, \cr
         2  \tab    \code{+.timeDate}   
            \tab    Performs arithmetic + ops on 'timeDate' objects, \cr
         3  \tab    \code{-.timeDate}   
            \tab    Performs arithmetic - ops on 'timeDate' objects, \cr
         4  \tab    \code{Ops.timeDate}         
            \tab    'Ops' generic functions for 'timeDate' objects, \cr
         5  \tab    \code{diff.timeDate}        
            \tab    Returns suitably lagged and iterated differences, \cr
         6  \tab    \code{difftimeDate}     
            \tab    Returns a difference of two 'timeDate' objects, \cr
         7  \tab    \code{c.timeDate}   
            \tab    Concatenates objects of class 'timeDate', \cr
         8  \tab    \code{rep.timeDate}         
            \tab    Replicates objects of class 'timeDate', \cr
         9  \tab    \code{start.timeDate}       
            \tab    Extracts the first object of a 'timeDate' vector, \cr
        10  \tab    \code{end.timeDate}         
            \tab    Extracts the last object of a 'timeDate' vector, \cr
        11  \tab    \code{modify.timeDate}       
            \tab    Sorts, rounds or truncates a 'timeDate' object, \cr
        12  \tab    \code{rev.timeDate}         
            \tab    Reverts  a 'timeDate' vector object. \cr           
     		\tab
    		\tab	\cr
    		\tab
        	\tab	\bold{Transformations of 'timeDate' Objects:} \cr 
         1  \tab    \code{as.character.timeDate}        
            \tab    Returns a 'timeDate' object as character string, \cr
         2  \tab    \code{as.data.frame.timeDate}       
            \tab    Returns a 'timeDate' object as data frame, \cr
         3  \tab    \code{as.POSIXct.timeDate}      
            \tab    Returns a 'timeDate' object as POSIXct object, \cr
         4  \tab    \code{as.POSIXlt}       
            \tab    As POSIXlt, Use Method (Overwrite), \cr
         5  \tab    \code{as.POSIXlt.default}       
            \tab    Default method for POSIXlt, \cr
         6  \tab    \code{julian.timeDate}      
            \tab    Returns Julian day counts since 1970-01-01, \cr
         7  \tab    \code{julian.POSIXt}        
            \tab    A Julian Patch, \cr
         8  \tab    \code{atoms.timeDate}       
            \tab    Returns date/time atoms from a 'timeDate' object, \cr
         9  \tab    \code{atoms}        
            \tab    Extract atoms, Use Method, \cr
        10  \tab    \code{atoms.default}        
            \tab    Default method for atoms, \cr
        11  \tab    \code{months.timeDate}      
            \tab    Extract months atom from a 'timeDate' object.}

}


\usage{
\method{[}{timeDate}(x, \dots, drop = TRUE)
\method{+}{timeDate}(e1, e2)
\method{-}{timeDate}(e1, e2)
\method{Ops}{timeDate}(e1, e2)
\method{diff}{timeDate}(x, lag = 1, differences = 1, \dots)
difftimeDate(time1, time2, 
	units = c("auto", "secs", "mins", "hours", "days", "weeks"))

\method{c}{timeDate}(\dots, recursive = FALSE)
\method{rep}{timeDate}(x, times, \dots)
\method{start}{timeDate}(x, \dots)
\method{end}{timeDate}(x, \dots)
\method{modify}{timeDate}(x, method = c("sort", "round", "trunc", 
	units = c("secs", "mins", "hours", "days"))
\method{rev}{timeDate}(x)

\method{as.character}{timeDate}(x, \dots)
\method{as.data.frame}{timeDate}(x, \dots)
\method{as.POSIXct}{timeDate}(x, tz = "")
\method{julian}{timeDate}(x, \dots)
\method{atoms}{timeDate}(x, \dots)
\method{months}{timeDate}(x, abbreviate = NULL)
}


\arguments{
  
    \item{abbreviate}{
    	[months] - \cr
    	currently not used.
    	}
    \item{differences}{
    	[lag] - \cr
    	an integer indicating the order of the difference.
    	}
    \item{e1, e2}{
    	["+"][["-"]["Ops"] - \cr
    	usually objects of class \code{timeDate}, in the case of
    	addition and subtraction \code{e2} may be of class
    	\code{numeric}.
    	}
    \item{lag}{
    	[lag] - \cr
    	an integer indicating which lag to use.  
		}
	\item{recursive}{
		[c] - \cr
		a logical. If recursive  is set to \code{TRUE}, the function 
		recursively descends through lists combining all their elements 
		into a vector. 
		}
    \item{time1, time2}{
    	[difftime] - \cr
    	two objects objects of class \code{timeDate}.
    	}
    \item{times}{
    	[rep] - \cr
    	an optional non-negative integer. A vector giving the number of 
    	times to repeat each element if of length \code{length(x)}, or 
    	to repeat the whole vector if of length \code{1}.
    	}
    \item{tz}{
        inputs the time zone to POSIX objects, i.e. the time zone, 
        \code{zone}, or financial center string, \code{FinCenter}, 
        as used by \code{timeDate} objects.
        }
    \item{units}{
    	a character string denoting the date/time units in which the 
    	results are desired.
    	}
    \item{x}{
    	an object of class \code{timeDate}.
    	} 
    \item{\dots}{
        arguments passed to other methods.
        }
       
}


\value{

    \code{"["}
    \cr
    returns a subset from a \code{timeDate} object.
    \cr
    
    \code{"+"}\cr
    \code{"-"}
    \cr
    the plus operator \code{"+"} performs arithmetic "+" operation on 
    \code{timeDate} objects, and 
    the minus operator \code{"-"} returns a \code{difftime} object if 
    both arguments \code{e1} and \code{e2} are \code{timeDate} objects, 
    or returns a \code{timeDate} object \code{e2} seconds earlier than 
    \code{e1}.
    \cr
    
    \code{Ops.timeDate}
    \cr
    returns the \code{Ops} grouped object.
    \cr
    
    \code{diff}\cr
    \code{difftimeDate}
    \cr
    For the first function, \code{diff.timeDate}, if \code{x} is a vector 
    of length \code{n} and \code{differences=1}, then the computed result 
    is equal to the successive differences \code{x[(1+lag):n] - x[1:(n-lag)]}. 
    If \code{difference} is larger than one this algorithm is applied
    recursively to \code{x}. Note that the returned value is a vector 
    which is shorter than \code{x}.
    The second function, \code{difftimeDate}, takes a difference of two 
    \code{timeDate} objects and returns an object of class \code{difftime} 
    with an attribute indicating the units.
    \cr
    
    \code{c}\cr
    \code{rep}
    \cr
    \code{c} returns all its arguments to be coerced to a \code{timeDate} 
    object which is the type of the returned value, and 
    \code{rep} returns a vector of repeated elements belonging to the 
    same class as \code{x}.
    \cr
    
    \code{start}\cr
    \code{end}
    \cr
    return from \code{x} the earliest or latest entry as an object of 
    class \code{timeDate}, respectively.
    \cr
    
    \code{modify}\cr
    \code{rev}
    \cr
    \code{modify} returns \code{x} as a sorted, rounded or truncated 
    object of the same class, depending on the \code{method} selection, 
    and
    \code{rev} returns \code{x} as a \code{timeDate} object in reversed 
    order.
    \cr
    
    
    \code{as.character}\cr
    \code{as.data.frame}
    \cr
    return a \code{timeDate} object trnasformed into a character or a
    data frame formatted object.
    \cr
 
       
    \code{as.POSIXct}
    \cr
    return a \code{timeDate} object trnasformed into a POSIX type
    formatted object.
    \cr
    

    \code{julian}
    \cr
    return a \code{timeDate} object as a Julian count.
    \cr
    
    \code{atoms}\cr
    \code{months.timeDate}
    \cr
    extrac from a \code{timeDate} object the calendar atoms, i.e,
    the year, month, day, and optionally hour, minute and second.
    \cr
    
    
}


\details
{

    \bold{Mathematical Operations:}
    \cr\cr
    This is a collection of S3 methods for objects of class \code{timeDate}
    to perform mathematical operations. Included are methods to extracts 
    or replace subsets from \code{timeDate} objects, to perform arithmetic 
    \code{"+"} and \code{"-"} operations, to group 'Ops' generic functions, 
    to return suitably lagged and iterated differences, to return differences 
    of two \code{timeDate} objects, to concatenate objects, to replicate 
    objects, to rounds objects, to truncates objects, to extract the first 
    or last entry of a vector, to sort the objects of the elements of a 
    date/time vector, and to revert \code{timeDate} vector objects.
    \cr
    
    \bold{Transformation of Objects:}
    \cr\cr
    This is a collection of S3 methods for objects of class \code{timeDate}
    to transform those objects between different representations.
    Included are methods to transform \code{timeDate} objects to character 
    strings, to data frames, to POSIXct or POSIXlt objects, to Julian
    counts, to extract date/time atoms from calendar dates, and to 
    extract the months atom from a \code{timeDate} object.
    \cr

}


\notes{

    These functions were written for Rmetrics users using R and Rmetrics
    under Microsoft's Windows XP operating system where timze zones, 
    daylight saving times and holiday calendars are insuffeciently 
    supported. The functions are untested for other system environments, 
    but may be used.
    
    Please, also be aware of the notes remarked in the help page describing
    the \code{timeDate} class.
    
    IT IS IMPORTANT THAT YOU SET YOUR ENVIRONMENT VARIABLE TZ TO 'GMT',
    OTHERWISE SOME OF THE 'TIMEDATE' FUNCTIONS WOULD NOT PROPERLY WORK! 
   
}


\references
{
Bateman R.,  (2000);
    \emph{Time Functionality in the Standard C Library},
    Novell AppNotes, September 2000 Issue, 73--85.

ISO-8601, (1988);
    \emph{Data Elements and Interchange Formats -
    Information Interchange, Representation of Dates and Time},
    International Organization for Standardization,
    Reference Number ISO 8601, 14 pages.

James D.A., Pregibon D. (1992),
    \emph{Chronological Objects for Data Analysis},
    Reprint.
    
Ripley B.D., Hornik K. (2001);
    \emph{Date-Time Classes},
    R-News, Vol. 1/2 June 2001, 8--12.
    
Zivot, E., Wang J. (2003);
	\emph{Modeling Financial Time Series with S-Plus},
	Springer, New-York.
}


\examples{
## c -
   xmpBasics("\nStart: Create Character Vectors > ") 
   dts = c("1989-09-28", "2001-01-15", "2004-08-30", "1990-02-09")
   tms = c(  "23:12:55",   "10:34:02",   "08:30:00",   "11:18:23")
   dts; tms
   
## "+/-" - 
   xmpBasics("\nStart: Add One Day to a Given timeDate Object > ")
   GMT = timeDate(dts, FinCenter = "GMT")
   ZUR = timeDate(dts, FinCenter = "Europe/Zurich")
   GMT + 24*3600
   ZUR[2] - ZUR[1]
  
## "[" - 
   xmpBasics("\nNext: Subsets from and Lops for timeDate Objects > ")
   GMT[GMT < GMT[2]]
   ZUR[ZUR < ZUR[3]] == ZUR[1:3]

## diff - 
   xmpBasics("\nNext: Suitably Lagged and Iterated Differences > ")
   diff(GMT)
   diff(GMT, lag = 2)
   diff(GMT, lag = 1, diff = 2)
   difftimeDate(GMT[1:2], GMT[-(1:2)])
   
## c | rep - 
   xmpBasics("\nNext: Concatenate and Replicate timeDate Objects > ") 
   c(GMT[1:2], ZUR[1:2])
   c(ZUR[1:2], GMT[1:2])
   rep(ZUR[2], times = 3)
   rep(ZUR[2:3], times = 2) 

## round | truncate -
   xmpBasics("\nNext: Round and Truncate timeDate Objects > ")
   modify(GMT, "round", "days")
   modify(ZUR, "round", "days")
   modify(GMT, "trunc", "days")
   modify(ZUR, "trunc", "days")

## start | end | sort - 
   xmpBasics("\nNext: Extract First/Last, Sort timeDate Objects > ")
   c(start(ZUR), end(ZUR))
   modify(ZUR, "sort") 

## as -
   xmpBasics("\nNext: Convert timeDate Objects to Other Objects > ")
   as.character(ZUR)
   as.data.frame(ZUR)
   as.POSIXct(ZUR)
   
## julian - 
   xmpBasics("\nNext: Julian Time in Days Since 1970-01-01 > ")
   julian(ZUR)  
   as.integer(julian(ZUR))
   julian(ZUR, "days")  
   as.integer(julian(ZUR, "days"))
    
## atoms - 
   xmpBasics("\nNext: Atoms from a timeDate Object > ")
   atoms(ZUR)
   atoms(ZUR)[,3]
   atoms(ZUR)[, "d"]
}


\author{

    Diethelm Wuertz for this R-port.
    
}


\keyword{chron}


\eof
\name{DSTrules}

\alias{DSTrules}

\alias{Adelaide}
\alias{Algiers}
\alias{Amsterdam}
\alias{Anchorage}
\alias{Andorra}
\alias{Athens}
\alias{Auckland}
\alias{Bahrain}
\alias{Bangkok}
\alias{Beirut}
\alias{Belfast}
\alias{Belgrade}
\alias{Berlin}
\alias{Bogota}
\alias{Bratislava}
\alias{Brisbane}
\alias{Brussels}
\alias{Bucharest}
\alias{Budapest}
\alias{BuenosAires}
\alias{Cairo}
\alias{Calcutta}
\alias{Caracas}
\alias{Casablanca}
\alias{Cayman}
\alias{Chicago}
\alias{Copenhagen}
\alias{Darwin}
\alias{Denver}
\alias{Detroit}
\alias{Dubai}
\alias{Dublin}
\alias{Eastern}
\alias{Edmonton}
\alias{Frankfurt}
\alias{Helsinki}
\alias{HongKong}
\alias{Honolulu}
\alias{Indianapolis}
\alias{Istanbul}
\alias{Jakarta}
\alias{Jerusalem}
\alias{Johannesburg}
\alias{Kiev}
\alias{KualaLumpur}
\alias{Kuwait}
\alias{Lagos}
\alias{Lisbon}
\alias{Ljubljana}
\alias{London}
\alias{LosAngeles}
\alias{Luxembourg}
\alias{Madrid}
\alias{Manila}
\alias{Melbourne}
\alias{MexicoCity}
\alias{Monaco}
\alias{Montreal}
\alias{Moscow}
\alias{Nairobi}
\alias{Nassau}
\alias{NewYork}
\alias{Nicosia}
\alias{Oslo}
\alias{Pacific}
\alias{Paris}
\alias{Perth}
\alias{Prague}
\alias{Riga}
\alias{Riyadh}
\alias{Rome}
\alias{Seoul}
\alias{Shanghai}
\alias{Singapore}
\alias{Sofia}
\alias{Stockholm}
\alias{Sydney}
\alias{Taipei}
\alias{Tallinn}
\alias{Tehran}
\alias{Tokyo}
\alias{Tunis}
\alias{Vaduz}
\alias{Vancouver}
\alias{Vienna}
\alias{Vilnius}
\alias{Warsaw}
\alias{Winnipeg}
\alias{Zagreb}
\alias{Zurich}


\title{Daylight Saving Time Rules}


\description{

	These are functions for about 100 cities, which return the
	daylight saving time tables: The cities are:
	
	Adelaide Algiers Amsterdam Anchorage Andorra Athens Auckland Bahrain
	Bangkok Beirut Belfast Belgrade Berlin Bogota Bratislava Brisbane
	Brussels Bucharest Budapest BuenosAires Cairo Calcutta Caracas
	Casablanca Cayman Chicago Copenhagen Darwin Denver Detroit Dubai
	Dublin Eastern Edmonton Frankfurt Helsinki HongKong Honolulu
	Indianapolis Istanbul Jakarta Jerusalem Johannesburg Kiev
	KualaLumpur Kuwait Lagos Lisbon Ljubljana London LosAngeles
	Luxembourg Madrid Manila Melbourne MexicoCity Monaco Montreal Moscow
	Nairobi Nassau NewYork Nicosia Oslo Pacific Paris Perth Prague Riga
	Riyadh Rome Seoul Shanghai Singapore Sofia Stockholm Sydney Taipei
	Tallinn Tehran Tokyo Tunis Vaduz Vancouver Vienna Vilnius Warsaw
	Winnipeg Zagreb Zurich
	
	There are currently two synonymes available "Pacific" for Los Angeles
	and "Eastern" for New York. 
	
	Note that we leave the space in all double named cities like New York 
	or Hong Kong and don't use an underscore for it.
	
	All the entries are retrieved from the Ical library which is 
	available under GNU's GPL licence. 
	GPL 
	

}

\examples{
## data - 
   xmpBasics("\nStart: DST Rules for Zurich > ")
   Zurich()
}


\keyword{data}

\eof
\name{timeSeriesClass}

\alias{timeSeriesClass}

\alias{timeSeries}
\alias{timeSeries-class}
\alias{read.timeSeries}

\alias{as.timeSeries}
\alias{is.timeSeries}
\alias{print.timeSeries}
\alias{plot.timeSeries}
\alias{lines.timeSeries}
\alias{Ops.timeSeries}
\alias{[.timeSeries}   
\alias{head.timeSeries}
\alias{tail.timeSeries}

\alias{seriesData}
\alias{seriesPositions}
\alias{start.timeSeries}
\alias{end.timeSeries}
\alias{as.vector.timeSeries}
\alias{as.matrix.timeSeries}
\alias{as.data.frame.timeSeries}

\alias{applySeries}
\alias{cutSeries}
\alias{diffSeries}    
\alias{lagSeries} 
\alias{mergeSeries}
\alias{returnSeries}
\alias{revSeries}

\alias{alignDailySeries}
\alias{ohlcDailyPlot}


\title{timeSeries Class and Methods}


\description{
    
    A collection of functions and methods dealing with regular and
    irregular 'timeSeries' objects. Dates and times are implemented
    as 'timeDate' objects. Included are functions and methods for 
    the generation and representation of 'timeSeries' objects, and
    for mathematical operations.          
    \cr
    
    IMPORTANT: \cr
    The \code{timeDate} and \code{timeSeries} classes are so far
    tested only under MS Windows XP operating system. Note, that
    your time zone environment variable must be set to "GMT". The
    reason for this is, that the functions work internally with "GMT"
    POSIX date and time objects whereas the Daylight Saving Time is 
    added on top of this through the information in the Ical Calendar
    Library.
    \cr
    
    The functions and methods are:         

    \tabular{rll}{   
            \tab
            \tab    \cr
            \tab
            \tab    \bold{Generation of 'timeSeries' Objects:} \cr
        1   \tab    \code{timeSeries}   
            \tab    Creates a 'timeSeries' object from scratch, \cr
        2   \tab    \code{read.timeSeries}  
            \tab    Reads a 'timeSeries' from a spreadsheet, \cr
        3   \tab    \code{as.timeSeries}    
            \tab    S3: Creates dummy 'time Series' from a 'matrix', \cr
        4   \tab    \code{is.timeSeries}    
            \tab    S3: Tests for a 'timeSeries' object, \cr
        5   \tab    \code{print.timeSeries}     
            \tab    S3: Print method for a 'timeSeries' object, \cr
        6   \tab    \code{plot.timeSeries}  
            \tab    S3: Plot method for a 'timeSeries' object, \cr
        7   \tab    \code{lines.timeSeries}     
            \tab    S3: Lines method for a 'timeSeries' object, \cr
        8   \tab    \code{Ops.timeSeries}   
            \tab    S3: Arith method for a 'timeSeries' object, \cr
        9   \tab    \code{[.timeSeries}     
            \tab    S3: "[" method for a 'timeSeries' object, \cr
        10  \tab    \code{head.timeSeries}  
            \tab    S3: returns the head of a 'timeSeries' object, \cr
        11  \tab    \code{tail.timeSeries}   
            \tab    S3: returns the tail of a 'timeSeries' object. \cr           
            \tab
            \tab    \cr
            \tab
            \tab    \bold{Representation of 'timeSeries' Objects:} \cr
         1  \tab    \code{seriesData}       
            \tab    Extracts data slot from a 'timeSeries', \cr
         2  \tab    \code{seriesPositions}      
            \tab    Extracts positions slot from a 'timeSeries', \cr
         3  \tab    \code{start.timeSeries}         
            \tab    S3: Extracts start date of a 'timeSeries', \cr
         4  \tab    \code{end.timeSeries}       
            \tab    S3: Extracts end date of a 'timeSeries', \cr
         5  \tab    \code{as.vector.timeSeries}         
            \tab    S3: Converts a 'timeSeries' to a vector, \cr
         6  \tab    \code{as.matrix.timeSeries}         
            \tab    S3: Converts a 'timeSeries' to a matrix, \cr
         7  \tab    \code{as.data.frame.timeSeries}         
            \tab    S3: Converts a 'timeSeries' to a data.frame. \cr           
            \tab
            \tab    \cr
            \tab
            \tab    \bold{Math Operations of 'timeSeries' Objects:} \cr
         1  \tab    \code{applySeries}      
            \tab    Applies a function to margins of a 'timeSeries', \cr
         2  \tab    \code{alignDailySeries}         
            \tab    Aligns a daily 'timeSeries' to new positions, \cr             
         3  \tab    \code{cutSeries}        
            \tab    Cuts out a piece from a 'timeSeries' object, \cr\       
         4  \tab    \code{mergeSeries}      
            \tab    Merges a 'timeSeries' object with a 'matrix', \cr
         5  \tab    \code{ohlcDailyPlot}      
            \tab    Plots openhighlowclose bar chart, \cr
         6  \tab    \code{revSeries}   
            \tab    S3: rev method for a 'timeSeries' object, \cr
         7  \tab    \code{diffSeries}  
            \tab    S3: diff method for a 'timeSeries' object, \cr
         8  \tab    \code{lagSeries}   
            \tab    S3: lag method for a 'timeSeries' object, \cr
         9  \tab    \code{returnSeries}         
            \tab    Computes returns from a 'timeSeries' object. }
        
}


\usage{
timeSeries(data, charvec, units = NULL, format = "ISO", zone = "GMT", 
    FinCenter = myFinCenter, title = NULL, documentation = NULL, ...) 
read.timeSeries(file, zone = "GMT", FinCenter = "", title = "", 
    documentation = "", sep = ";")
    
as.timeSeries(x, dimnames = TRUE, format = "")
is.timeSeries(object) 
\method{print}{timeSeries}(x, ...)
\method{plot}{timeSeries}(x, reference.grid = TRUE, lty = 1, ...) 
\method{lines}{timeSeries}(x, ...)
\method{Ops}{timeSeries}(e1, e2)
\method{[}{timeSeries}(x, i = min(1, nrow(x@Data)):nrow(x@Data), 
    j = min(1, ncol(x@Data)):ncol(x@Data))
\method{head}{timeSeries}(x, \dots)
\method{tail}{timeSeries}(x, \dots)

seriesData(object)
seriesPositions(object)
\method{start}{timeSeries}(x, \dots)
\method{end}{timeSeries}(x, \dots)
\method{as.vector}{timeSeries}(x, mode = "any")
\method{as.matrix}{timeSeries}(x)
\method{as.data.frame}{timeSeries}(x, row.names = NULL, optional = NULL)

applySeries(x, from, to, FUN = colMeans, colNames = NULL, ...) 
cutSeries(x, from, to)
diffSeries(x, lag = 1, diff = 1, trim = FALSE, pad = NA)
lagSeries(x, k = 1, trim = FALSE, colNames = NULL)
mergeSeries(x, y, units = NULL)
returnSeries(x, type = c("continuous", "discrete"), percentage = FALSE, 
    trim = TRUE, digits = 4)
revSeries(x)
    
alignDailySeries(x, method = c("before", "after", "interp", "fillNA"), 
    include.weekends = FALSE)
ohlcDailyPlot(x, volume = TRUE, colOrder = c(1:5), units = 1e6, 
    xlab = c("Date", "Date"), ylab = c("Price", "Volume"), 
    main = c("O-H-L-C", "Volume"), grid.nx = 7, grid.lty = "solid", \dots) 
}


\arguments{
  
    \item{charvec}{
        a character vector of dates and times.
        }
    \item{colNames}{
        [applySeries][lag] - \cr
        a character string, which allows to overwrite the current
        column names of a \code{timeSeries} object. By default 
        \code{NULL} which means that the column names are selected
        automatically.
        }   
    \item{colOrder}{
        [ohlcDailyPlot] - \cr 
        an integer vector which gives the order of the prices and the
        volume in the input object. By default the following order of
        columns from 1 to 5 is assumed: Open, high, low, close, and volume.
        }
    \item{data}{
        a \code{data.frame} or a \code{matrix} object of numeric data.
        }
    \item{diff}{
        [diffSeries] - \cr
        an integer indicating the order of the difference. By default 1.
        }
    \item{digits}{
        [returnSeries] - \cr
        an integer value. The number of digits to be printed in the 
        output.
        }
    \item{dimnames}{
        [as.timeSeries] - \cr
        a logical, if \code{TRUE} the dimension names of the
        matrix are assigned to the time series object.
        }
    \item{documentation}{
        optional documentation string, or a vector of character strings.
        }
    \item{e1, e2}{
        [Ops] - \cr   
        two objects of class \code{timeSeries}.
        }
    \item{file}{
        the filename of a spreadsheet data set from which
        to import the data records.
        }
    \item{FinCenter}{
        a character with the the location of the  financial center named 
        as "continent/city". 
        }
    \item{format}{
        the format specification of the input character vector,
        \cr
        [as.timeSeries] - \cr
        a character string with the format in POSIX notation to be passed 
        to the time series object.
        }
    \item{from, to}{
        starting date and end date, \code{to} must be after \code{from}.
        }
    \item{FUN}{ 
        [applySeries] - \cr
        a function to use for aggregation, by default \code{sum}.
        }
    \item{grid.lty, grid.nx}{
        [ohlcDailyPlot] - \cr
        The type of grid line and the number of grid lines used in the
        plot.
        }
    \item{i, j}{
        ["["] - \cr 
        index arguments used for subsettings.
        }        
     \item{include.weekends}{   
        [alignDailySeries] - \cr
        a logical value. Should weekend dates be included or removed
        from the series.
        } 
    \item{k}{   
        [lagSeries] - \cr   
        an integer value. The number of lags (in units of observations).
        By default 1.
        }
    \item{lag}{   
        [diffSeries] - \cr
        an integer indicating which lag to use. By default 1.
        }
    \item{lty}{   
        [plot] - \cr
        an integer value, the typ of line to be drawn. By default 1,
        a solid line.
        }       
    \item{main}{
        [ohlcDailyPlot] - \cr
        a character string to title the price and volume plot.
        }
    \item{method}{ 
        [alignDailySeries] - \cr
        the method to be used for the alignment. A character string, one
        of \code{"before"}, use the data from the row whose position is
        just before the unmatched position, or \code{"after"}, use the 
        data from the row whose position is just after the unmatched 
        position, or \code{"linear"}, interpolate linearly between 
        \code{"before"} and \code{"after"}. 
        }
    \item{mode}{
        [as.vector] - \cr
        A character string giving an atomic mode, or \code{"any"}.
        }  
    \item{optional, row.names}{
        [as.data.frame] - \cr
        both arguments are currently not used.
        }       
    \item{object}{
        [is][seriesData][seriesPositions] -    
        an object of class \code{timeSeries}.
        }
    \item{pad}{
        [diffSeries] - \cr
        which value should get the padded values? By default \code{NA}.
        Another choice often used would be zero.
        }
    \item{percentage}{
        [returnSeries] - \cr
        a logical value. By default \code{FALSE}, if \code{TRUE} the 
        series will be expressed in percentage changes.
        }
    \item{reference.grid}{
        [plot] - \cr    
        a logical value. Should a grid be added to the plot? By
        default \code{TRUE}.
        } 
    \item{sep}{
        [read.timeSeries] - \cr
        the field seperator used in the spreadsheet file to separate 
        columns.
        }
    \item{title}{
        an optional title string, if not specified the inputs data 
        name is deparsed.
        }
    \item{trim}{
        [diffSeries][returnSeries] - \cr
        a logical value. By default \code{TRUE}, the first missing 
        observation in the return series will be removed. 
        }
    \item{type}{
        [returnSeries] - \cr
        a character string specifying how to compute the returns. Valid 
        choices are: \code{continuous} and \code{discrete}. For the 
        default \code{type="continuous"}, the returns are calculated as 
        the logarithmic differences, otherwise if \code{type="discrete"}, 
        the returns are calculated as percentage changes. 
        }
    \item{units}{   
        an optional units string, \code{NULL} defaults an empty string.
        \cr
        [mergeSeries] - \cr
        an integer string or vector which allows to rename the units 
        in the units Slot of the \code{timeSeries} object.
        \cr
        [ohlcDailyPlot] - \cr
        a numeric value, specifying in which multiples the volume should
        be referenced on the plot labels. By default 1e6, i.e. in units
        of 1 Million.
        }
    \item{volume}{
        [ohlcDailyPlot] - \cr
        a logigical value. Should a volume plot added to the OHLC Plot.
        By default \code{TRUE}.
        }
    \item{x}{
        [as] - \cr   
        a \code{matrix} type object to be converted.\cr
        [as.vector][as.matrix][as.data.frame] -\cr
        [applySeries] - \cr
        [cut][end][mergeSeries][plot][print][rev][start] - \cr
        an object of class \code{timeSeries}.
        }
    \item{xlab, ylab}{
        [ohlcDailyPlot] - \cr
        two string vectors to name the x and y axis of the price and
        volume plot.
        }
    \item{y}{
        [mergeSeries] - \cr   
        a \code{matrix} type object to be merged with an object of
        class \code{timeSeries}. Must have the same number of rows.
        }
    \item{zone}{
        the time zone or financial center where the data were recorded.
        }   
    \item{\dots}{
        arguments passed to other methods.
        }
       
}


\value{

    \code{timeSeries}\cr
    \code{read.timeSeries}\cr
    \code{as.timeSeries}
    \cr
    return a S4 object of class \code{timeSeries}.
    \cr
    
    \code{seriesData}\cr
    \code{seriesPositions}
    \cr
    extract the \code{@Data} and \code{@position} slots from a 
    \code{timeSeries} object. Thus, \code{seriesData} returns an 
    object of class \code{matrix}, and \code{seriesPositions}
    returns an object of class \code{timeDate}.
    \cr
    
    \code{is.timeSeries}
    \cr
    returns \code{TRUE} or \code{FALSE} depending on whether its
    argument is of \code{timeSeries} type or not.
    \cr
        
    \code{aggregateSeries}\cr
    \code{applySeries}\cr
    \code{cutSeries}\cr
    \code{mergeSeries}\cr
    \code{returnSeries}\cr
    \code{revSeries}
    \cr
    return a S4 object of class \code{timeSeries}.
    \cr
    
    \code{end, start}
    \cr
    return a S4 object of class \code{timedate}. These are the 
    start and end dates of a \code{timeSeries} object.
    \cr
    
    \code{as.vector}\cr
    \code{as.matrix}\cr
    \code{as.data.frame}
    \cr
    these are methods which convert a S4 object of class \code{timeSeries}
    either to a vector, a matrix or to a data frame.
    \cr
    
    \code{plot}\cr
    \code{print}
    \cr
    plot and print methods for an object of class \code{timeSeries}.
    Note that the plot function requires the packages \code{its} and
    \code{Hmisc}.
    \cr
        
}


\details{

    \bold{Generation of Time Series Objects:}
    \cr\cr
    We have defined a \code{timeSeries} class which is in many aspects similar
    to the S-Plus class with the same name, but has also some important
    differeneces. The class has seven Slots, the 'Data' slot which holds 
    the time series data in matrix form, the 'position' slot which holds
    the time/date as a character vector, the 'format' and 'FinCenter'
    slots which are the same as for the 'timeDate' object, the 'units'
    slot which holds the column names of the data matrix, and a 'title'
    and a documentation' slot which hold descriptive character strings.
    Date and time is managed in the same way as for \code{timeDate} objects.

}


\notes{

    These functions were written for Rmetrics users using R and Rmetrics
    under Microsoft's Windows operating system where timze zones, 
    daylight saving times and holiday calendars are insuffeciently 
    supported. The functions are untested for other system environments, 
    but may be used.
    
    Please, also be aware of the notes remarked in the help page describing
    the \code{timeDate} class.
    
    IT IS IMPORTANT THAT YOU SET YOUR ENVIRONMENT VARIABLE TZ TO 'GMT',
    OTHERWISE SOME OF THE 'TIMEDATE' FUNCTIONS WOULD NOT PROPERLY WORK! 

}



\examples{
## data - 
   xmpBasics("\nStart: Load Microsoft Data > ")
   data(msft.dat)
   msft.dat[1:3, ]

## timeSeries -
   xmpBasics("\nNext: Create a timeSeries Object > ")
   myFinCenter = "GMT"
   close = msft.dat[, 5]
   ts = timeSeries(close, as.character(msft.dat[, 1]), 
     format = "\%m/\%d/\%Y", units = "MSFT")
   class(ts)
   ts[1:3,]
   c(start(ts), end(ts))
    
## cutSeries -    
   xmpBasics("\nNext: Cut out April Data from 2001 > ")
   ts.Apr01 = cutSeries(ts, "2001-04-01", "2001-04-30") 
   ts.Apr01

## returnSeries -  
   xmpBasics("\nNext: Compute Returns > ")
   # Compute Returns:
   args(returnSeries)
   # Continuous Returns:
   returnSeries(ts.Apr01)
   # Discrete Returns:
   returnSeries(ts.Apr01, type = "discrete")
   # Don't trim:
   returnSeries(ts.Apr01, trim = FALSE)
   # Use Percentage Values:
   returnSeries(ts.Apr01, percentage = TRUE, trim = FALSE)

## mergeSeries -    
   xmpBasics("\nNext: Merge Series with Returns > ")
   # Include last Day from March:
   ts.APR01 = cutSeries(ts, "2001-03-29", "2001-04-30") 
   ts.merged = mergeSeries(x = ts.APR01, 
     returnSeries(ts.APR01, trim = FALSE)@Data, units = c("MSFT", "Returns"))
   ts.merged
    
## alignDailySeries -     
   xmpBasics("\nNext: Align with NA > ")
   args(alignDailySeries)
   ts.ret = returnSeries(ts.APR01, trim = TRUE)
   GoodFriday(2001)   
   EasterMonday(2001) 
   alignDailySeries(ts.ret, method = "fillNA", include.weekends = FALSE)
   alignDailySeries(ts.ret, method = "fillNA", include.weekends = TRUE)
    
## alignDailySeries - 
   xmpBasics("\nNext: Interpolate > ")
   ts.ret
   alignDailySeries(ts.ret, method = "interp", include.weekend = FALSE)
   alignDailySeries(ts.ret, method = "interp", include.weekend = TRUE)

## applySeries -   
   xmpBasics("\nNext: Aggregate weekly > ")
   GoodFriday(2001)
   to = timeSequence(from = "2001-04-11", length.out = 3, 
     by = "weeks", format = "\%Y-\%m-\%d") 
   from = to - 6*24*3600
   data.frame(from, to)
   applySeries(ts.ret, from, to, FUN = sum)
}
   

\author{

    Diethelm Wuertz for this R-port.
    
}


\keyword{chron}


\eof
\name{holidayCalendars}

\alias{holidayCalendars}

\alias{easter}
\alias{holiday}

\alias{holiday.NYSE}

\alias{on.or.after}
\alias{on.or.before}
\alias{nth.of.nday} 
\alias{last.of.nday}

\alias{sjulian}
\alias{sdate}
\alias{sday.of.week}
\alias{sleap.year}
\alias{print.sdate}

\alias{fjulian}
\alias{.julian}
\alias{month.day.year}
\alias{leap.year}
\alias{day.of.week}


\title{Holiday Calendars and Utilities}


\description{
    
    A collection of functions and methods dealing with holiday calendars. 
    Included are functions for the computation of the date of easter
    and related feasts. These functions allow the generation of holiday 
    calendars. Included are some utility functions to compute special 
    dates from n-dates, and to manage dates formatted in the ISO-8601 
    integer \code{CCYYMMDD} calendar format. Furthermore, functions are 
    available to convert Julian counts to formatted calendar dates and 
    vice versa. These are SPlus like functions.
    
    The functions and methods are:   
    
    \tabular{rll}{   
    		\tab
    		\tab	\bold{Generation of Holiday Calendars:} \cr
         1  \tab    \code{easter}   
            \tab    Returns date of easter or related feasts as 'sdate'-s, \cr
         2  \tab    \code{holiday}  
            \tab    Returns a holiday date of G7 and CH as 'sdate', \cr
         3  \tab    \code{holiday.NYSE}    
            \tab    Computes 'timeDate' object for full-day NYSE holidays. \cr           
    		\tab
    		\tab	\cr
    		\tab
    		\tab	\bold{N-Day Functions:} \cr
         1  \tab    \code{on.or.after}  
            \tab    Date in month that is a "n-day" on-or-after a "date", \cr
         2  \tab    \code{on.or.before}     
            \tab    Date in month that is a "n-day" on-or-before a "date", \cr
         3  \tab    \code{nth.of.nday}  
            \tab    The "n-th" ocurrance of a "n"day in year/month, \cr
         4  \tab    \code{last.of.nday}     
            \tab    The last "n"day in a given year/month. \cr
            \tab
    		\tab	\cr
    		\tab
    		\tab	\bold{ISO-8601 Day FRunctions:} \cr
         1  \tab    \code{sjulian}      
            \tab    Julian day counts from ISO formatted dates, \cr
         2  \tab    \code{sdate}        
            \tab    ISO-8601 formatted dates from Julian day counts, \cr
         3  \tab    \code{sday.of.week}     
            \tab    day of week from \code{CCYYMMDD} formatted dates, \cr
         4  \tab    \code{sleap.year}   
            \tab    Decides if \code{CCYYMMDD} is a leap year or not, \cr
         5  \tab    \code{print}    
            \tab    S3 Print method for objects of class \code{sdate}. \cr           
            \tab
    		\tab	\cr
    		\tab
    		\tab	\bold{SPlus like Functions:} \cr
        1	\tab	\code{fjulian} 		 
			\tab  	Calculates Julian counts from different formats, \cr
		2	\tab	\code{.julian} 		 
			\tab 	Converts formatted calendar dates to Julian counts, \cr
    	3	\tab	\code{month.day.year} 
    		\tab  	Returns months, days, and years from Julian counts, \cr
		4	\tab	\code{leap.year} 	 
			\tab  	Deciding if a year is a leap year or not, \cr
		5	\tab	\code{day.of.week}	 
			\tab  	Determines the day of week, starting with Sunday as 0.}
                
}


\usage{
easter(year, shift = 0)
holiday(year, holiday = "Easter")
holiday.NYSE(y = currentYear)

on.or.after(year, month, day, nday)
on.or.before(year, month, day, nday)
nth.of.nday(year, month, nday, nth) 
last.of.nday(year, month, lastday, nday)

sjulian(sdates, origin = 19600101)
sdate(julians, origin = 19600101)
sday.of.week(sdates)
sleap.year(sdates)

\method{print}{sdate}(x, \dots)

fjulian(fdates, origin = 19600101, order = 'mdy', cc = 20)
.julian(m, d, y, origin = c(month = 1, day = 1, year = 1960)

month.day.year(jul, origin = c(month = 1, day = 1, year = 1960))
leap.year(y) 
day.of.week(month, day, year)
}


\arguments{

    \item{cc}{
    	[fjulian] - \cr
		a numeric value denoting the century.
		}
	\item{day}{ 
        an integer vector of day numbers, [DD].
        [day.of.week] - cr
        vector of integer day numbers.
        }
    \item{fdates}{
		[fjulian] - \cr
		a character vector of formatted Gregorian dates.
		}
	\item{holiday}{
        the name of an ecclestial or public holiday in the G7
        countries or Switzerland, see the list below.
        }
    \item{jul}{
		[month.day.year] - \cr
		vector of Julian dates (the number of days since origin).
		} 
	\item{julians}{
        a numeric vector of Julian Day Counts.
        }
    \item{lastday}{
        the last day in the calendar month.
        }
    \item{m, d, y}{
    	[.julian] - \cr
		vector of month, day and year numbers. The years should be 
		entered in their full four-digit form; it is assumed that 
		two-digit years refer to the first century.
		} 		
	\item{month}{
        an integer vector of month numbers, [MM].\cr
        [day.of.week] - cr
        vector of integer month numbers.
        }
    \item{nday}{
        an integer vector with entries ranging from 
        \code{0} (Sunday) to \code{6} (Saturday).
        }
    \item{nth}{
        an integer vector numbering the n-th occurence.
        }
    \item{order}{
    	[fjulian] - \cr
		a character string, indicating the order of year, month 
		and day.
		}
    \item{origin}{
        the origin date of the counter, in ISO-8601 date format,
        [CCYYMMDD]. By default Januar 1st, 1960.
        }
    \item{sdates}{
        a numeric vector of ISO-8601 formatted Gregorian dates,
        [CCYYMMDD].
        }
    \item{shift}{
        a numeric value, the n-day shift. By default the shift is
        set to zero and the function returns the date of Easter.
        }
    \item{x}{
        an object of class \code{"sdate"}. This is an integer
        value or integer vector formatted as ISO-8601 CCYYMMDD.
        }
    \item{year}{
        an integer vector of years, [CCYY].
        [day.of.week] - cr
        vector of integer year numbers.
        }
    \item{\dots}{
        additional optional arguments to be passed.     
        }
        
}


\value{

    \code{easter}\cr
    \code{holiday}\cr
    \code{holiday.NYSE}
    \cr
    return an ISO-8601 formatted calendar date \code{CCYYMMDD}, an
    object of class \code{"sdate"} which represents an integer
    value or vector.
    \cr

    \code{on.or.after},\cr
    \code{on.or.before},\cr
    \code{nth.of.nday},\cr
    \code{last.of.nday}
    \cr
    return like the holiday functions an ISO-8601 formatted calendar 
    date integer value or vector.
    \cr
    
    \code{sjulian}\cr
    \code{sdates}\cr
    \code{sday.of.week}\cr
    \code{sleap.year}
    \cr
    the Julian day counter returns a numeric vector of Julian day counts,
    \code{sdates} returns a numeric vector of ISO-8601 formatted dates, 
    i.e [CCYYMMDD], the day of the week function returns a numeric vector 
    with entries  between \code{0} (Sunday) and \code{6} (Saturday) and
    the leap year function returns a logical vector with entries TRUE or 
    FALSE, weather the date falls in a leap year or not.
    \cr
    
    \code{fjulian} 
  	\cr
  	returns a numeric vector of Julian Day Counts.
	When \code{julian} is called, a vector of Julian counts corresponding 
	to the input values is returned. If \code{month.day.year} is called, 
	a list with members \code{month}, \code{day}, and \code{year} is 
	returned for the given Julian dates. 
	\cr
	
	\code{leap.year} 
	\cr
	returns a logical vector indicating whether the input years are leap 
	years or not.
	\cr
	
	\code{day.of.week} 
	\cr
	returns a number between 0 and 6 that specifies the day of the week 
	of the given date; 0 refers to Sunday. 

}


\details{

    \bold{Holiday Calendar:}
    \cr\cr
    Easter is the central ecclestial holiday. Many other holidays
    are related to this feast. The function \code{easter} computes
    the dates of easter and related ecclestial holidays for the 
    requested year vector. \code{holiday} calculates the dates of 
    ecclestial or publich holidays in the G7 countries, e.g. 
    \code{holiday(2003, "GoodFriday")}. \code{holidays.db} is our 
    Data Base of World Wide Holidays. The database contains holiday 
    functions automatically loaded by the \code{fBasics} library at 
    startup time. The user can add additional holiday functions to 
    this data base. The information for the holiday data base were 
    collected from several web pages about holiday calendars.
    The following ecclestial and public \code{[HOLIDAY]} functions 
    in the G7 countries and Switzerland are available: 
    \cr\cr
    \emph{Holidays Related to Easter:} 
    \cr
    Septuagesima, Quinquagesima, AshWednesday, PalmSunday,
    GoodFriday,  EasterSunday, Easter, EasterMonday, 
    RogationSunday, Ascension, Pentecost, PentecostMonday, 
    TrinitySunday CorpusChristi. 
    \cr 
    \emph{Holidays Related to Christmas:} 
    \cr
    ChristTheKing, Advent1st, Advent1st, Advent3rd, 
    Advent4th, ChristmasEve, ChristmasDay, BoxingDay, 
    NewYearsDay. 
    \cr
    \emph{Other Ecclestical Feasts:} 
    \cr
    SolemnityOfMary, Epiphany, PresentationOfLord, 
    Annunciation, TransfigurationOfLord, AssumptionOfMary, 
    AssumptionOfMary, BirthOfVirginMary, CelebrationOfHolyCross, 
    MassOfArchangels, AllSaints, AllSouls. 
    \cr
    \emph{CHZurich - Public Holidays:} 
    \cr
    CHBerchtoldsDay, CHSechselaeuten, CHAscension, 
    CHConfederationDay, CHKnabenschiessen. 
    \cr
    \emph{GBLondon - Public Holidays:} 
    \cr
    GBMayDay, GBBankHoliday, GBSummerBankHoliday, 
    GBNewYearsEve.
    \cr
    \emph{DEFrankfurt - Public Holidays:} 
    \cr
    DEAscension, DECorpusChristi, DEGermanUnity, DEChristmasEve,
    DENewYearsEve. 
    \cr
    \emph{FRParis - Public Holidays:} 
    \cr
    FRFetDeLaVictoire1945, FRAscension, FRBastilleDay, 
    FRAssumptionVirginMary, FRAllSaints, FRArmisticeDay. 
    \cr
    \emph{ITMilano - Public Holidays:} 
    \cr
    ITEpiphany, ITLiberationDay, ITRepublicAnniversary, 
    ITAssumptionOfVirginMary, ITAllSaints, ITWWIVictoryAnniversary, 
    ITStAmrose, ITImmaculateConception. 
    \cr
    \emph{USNewYork/USChicago - Public Holidays:} 
    \cr
    USNewYearsDay, USInaugurationDay, USMLKingsBirthday, 
    USLincolnsBirthday, USWashingtonsBirthday, USMemorialDay, 
    USIndependenceDay, USLaborDay,  USColumbusDay, USElectionDay, 
    USVeteransDay, USThanksgivingDay, USChristmasDay, 
    USCPulaskisBirthday, USGoodFriday. 
    \cr
    \emph{CAToronto/CAMontreal - Public Holidays:} 
    \cr
    CAVictoriaDay, CACanadaDay, CACivicProvincialHoliday, 
    CALabourDay, CAThanksgivingDay, CaRemembranceDay. 
    \cr
    \emph{JPTokyo/JPOsaka - Public Holidays:} 
    \cr
    JPNewYearsDay, JPGantan, JPBankHolidayJan2, JPBankHolidayJan3,
    JPComingOfAgeDay, JPSeijinNoHi, JPNatFoundationDay,
    JPKenkokuKinenNoHi, JPGreeneryDay, JPMidoriNoHi, 
    JPConstitutionDay, JPKenpouKinenBi, JPNationHoliday, 
    JPKokuminNoKyujitu, JPChildrensDay, JPKodomoNoHi, 
    JPMarineDay, JPUmiNoHi, JPRespectForTheAgedDay,
    JPKeirouNoHi, JPAutumnalEquinox, JPShuubun-no-hi, 
    JPHealthandSportsDay, JPTaiikuNoHi, JPNationalCultureDay, 
    JPBunkaNoHi, JPThanksgivingDay, JPKinrouKanshaNohi, 
    JPKinrou-kansha-no-hi, JPEmperorsBirthday,
    JPTennou-tanjyou-bi, JPTennou-tanjyou-bi. 
    \cr
    All the holiday functions are listed in the data file \code{holidays.R}.
    Additional holidays, which are not yet available there, can be added
    to this data base file.
    \cr\cr

    
    \bold{n-Day Functions:}
    \cr\cr
    The function \code{on.or.after}
    calculates the date in a given month and year that is a n-day 
    ON OR AFTER a given date.\cr    
    The function \code{on.or.before}
    calculates the date in a given month and year that is a n-day 
    ON OR BEFORE a given date. \cr  
    The function \code{nth.of.nday}
    calculates the n-th ocurrance of a n-day in a given month and 
    year. \cr   
    The function code{last.of.nday}
    calculates the last n-day in a given month and year.
    \cr
    
    
    \bold{sdate Class:}
    \cr\cr
    
    \code{"sdates"} represent a class of integer formatted \code{CCYYMMDD}
    ISO-8601 calendar dates.
    Note, that the \code{s*} indicates "standard" or "simple" ISO-8601 
    date format where \code{CC} denotes the century, \code{YY} the year, 
    \code{MM} the month, and \code{DD} the day, e.g 20031213. This
    formated was included to the \code{fbasics} library already some
    years ago. It is likely that this date format will be replaced 
    in the near future by the new R objects of class. \code{"Date"}.

}


\notes{

	Most of the functions were written for R Version 1.5. With the new
	\code{Date Class} becoming available in R 1.9.0 these functions will 
	undergo a revision in the near future.
	
}


\references{

ISO-8601 (1988); 
    \emph{Data Elements and Interchange Formats -
    Information Interchange, Representation of Dates and Time},
    International Organization for Standardization,
    Reference Number ISO 8601, 14 pages.
    
Therneau T. (1991); 
	\emph{S-plus Date Routines}, 
	www.statlib.org

}


\examples{
## easter -
   xmpBasics("\nStart: Easter and Easter Related Feasts > ")
   # Dates for Easter and Pentecost from 2000 until 2010:
   easter(2000:2010)
   GoodFriday = easter(2000:2010, -2) # Tis is Good Friday
   GoodFriday
   holiday(2000:2010, "Easter")
   holiday(2000:2010, "GoodFriday")  
   
## holidays -   
   xmpBasics("\nNext: Alternatively You can use > ")
   Easter(2000:2010)
   GoodFriday(2000:2010)
  
## holiday.NYSE -
   xmpBasics("\nNext: Holiday Calendar for the New York Stock Exchange > ")
   holiday.NYSE()
   
## on.or.after -
   xmpBasics("\nStart: on.or.after > ")
   # What date had the first advent 2001?
   # The first advent is the Sunday on or after November 27th.
   on.or.after(year = 2001, month = 11, day = 27, nday = 0)
   
## on.or.before -
   xmpBasics("\nNext: on.or.before > ")
   # What date had Monday on or after April, 1st, 2001?
   on.or.before(year = 2001, month = 11, day = 27, nday = 1)
   
## nth.of.nday -
   xmpBasics("\nNext: nth.of.nday > ")
   # What date had the second Sunday in October 1980?
   nth.of.nday(year = 1980, month = 10, nday = 0, nth = 2)
   Continue = xmpBasics("Press any key > ")
  
## last.of.nday -
   xmpBasics("\nNext: last.of.nday > ")   
   # What date had the last Monday in September, 2002?
   last.of.nday(year = 1996, month = 9, lastday = 31, nday = 1)  
   
## fdates - fjulian -
   xmpBasics("\nStart: Convert Formatted Gregorian Dates > ")
   fdates = c("8/11/73", "08-11-73", "August 11 1973", "Aug11/73")
   fdates
   fjulian(fdates) 
   
## fdates - fjulian -
   xmpBasics("\nNext: Convert with 'dmy' Order > ")
   fdates = c("11/8/73", "11-08-73", "11 August 1973", "11Aug73")
   fjulian(fdates, order = 'dmy')
   
## .julian - day.of.week -
   xmpBasics("\nNext: Day of Week > ")
   # The number of days from January 1, 1990 to each of:
   # January 15, 1990, February 15, 1991, March 15, 1992, etc.
   .julian(1:12, rep(15,12), 1990+(0:11), origin = c(1, 1, 1990))
   # November 12, 98, was a Wednesday.
   day.of.week(m = 11, d = 12, y = 98)
}


\author{

    Therry Therneau for the C program used by \code{fjulian},\cr
	Diethelm Wuertz for this \R-Port.
    
}


\keyword{chron}


\eof
\name{holidayDatabase}

\alias{holidayDatabase}


\alias{Septuagesima}
\alias{Quinquagesima}
\alias{AshWednesday}
\alias{PalmSunday}
\alias{GoodFriday}
\alias{Easter}
\alias{EasterSunday}
\alias{EasterMonday}
\alias{RogationSunday}
\alias{Ascension}
\alias{Pentecost}
\alias{PentecostMonday}
\alias{TrinitySunday}
\alias{CorpusChristi}
\alias{ChristTheKing}
\alias{Advent1st}
\alias{Advent2nd}
\alias{Advent3rd}
\alias{Advent4th}
\alias{ChristmasEve}
\alias{ChristmasDay}
\alias{BoxingDay}
\alias{NewYearsDay}
\alias{SolemnityOfMary}
\alias{Epiphany}
\alias{PresentationOfLord}
\alias{Annunciation}
\alias{TransfigurationOfLord}
\alias{AssumptionOfMary}
\alias{BirthOfVirginMary}
\alias{CelebrationOfHolyCross}
\alias{MassOfArchangels}
\alias{AllSaints}
\alias{AllSouls}
\alias{LaborDay}
\alias{CHBerchtoldsDay}
\alias{CHSechselaeuten}
\alias{CHAscension}
\alias{CHConfederationDay}
\alias{CHKnabenschiessen}
\alias{GBMayDay}
\alias{GBBankHoliday}
\alias{GBSummerBankHoliday}
\alias{GBMilleniumDay}
\alias{DEAscension}
\alias{DECorpusChristi}
\alias{DEGermanUnity}
\alias{DEChristmasEve}
\alias{DENewYearsEve}
\alias{FRFetDeLaVictoire1945}
\alias{FRAscension}
\alias{FRBastilleDay}
\alias{FRAssumptionVirginMary}
\alias{FRAllSaints}
\alias{FRArmisticeDay}
\alias{ITEpiphany}
\alias{ITLiberationDay}
\alias{ITAssumptionOfVirginMary}
\alias{ITAllSaints}
\alias{ITStAmrose}
\alias{ITImmaculateConception}
\alias{USDecorationMemorialDay}
\alias{USPresidentsDay}
\alias{USNewYearsDay}
\alias{USInaugurationDay}
\alias{USMLKingsBirthday}
\alias{USLincolnsBirthday}
\alias{USWashingtonsBirthday}
\alias{USMemorialDay}
\alias{USIndependenceDay}
\alias{USLaborDay}
\alias{USColumbusDay}
\alias{USElectionDay}
\alias{USVeteransDay}
\alias{USThanksgivingDay}
\alias{USChristmasDay}
\alias{USCPulaskisBirthday}
\alias{USGoodFriday}
\alias{CAVictoriaDay}
\alias{CACanadaDay}
\alias{CACivicProvincialHoliday}
\alias{CALabourDay}
\alias{CAThanksgivingDay}
\alias{CaRemembranceDay}
\alias{JPNewYearsDay}
\alias{JPGantan}
\alias{JPBankHolidayJan2}
\alias{JPBankHolidayJan3}
\alias{JPComingOfAgeDay}
\alias{JPSeijinNoHi}
\alias{JPNatFoundationDay}
\alias{JPKenkokuKinenNoHi}
\alias{JPGreeneryDay}
\alias{JPMidoriNoHi}
\alias{JPConstitutionDay}
\alias{JPKenpouKinenBi}
\alias{JPNationHoliday}
\alias{JPKokuminNoKyujitu}
\alias{JPChildrensDay}
\alias{JPKodomoNoHi}
\alias{JPMarineDay}
\alias{JPUmiNoHi}
\alias{JPRespectForTheAgedDay}
\alias{JPKeirouNOhi}
\alias{JPAutumnalEquinox}
\alias{JPShuubunNoHi}
\alias{JPHealthandSportsDay}
\alias{JPTaiikuNoHi}
\alias{JPNationalCultureDay}
\alias{JPBunkaNoHi}
\alias{JPThanksgivingDay}
\alias{JPKinrouKanshaNoHi}
\alias{JPEmperorsBirthday}
\alias{JPTennouTanjyouBi}
\alias{JPBankHolidayDec31}


\title{Holiday Calendars and Utilities}


\description{
    
    A collection of functions and methods dealing with holiday 
    calendars. 
   
}


\usage{
Septuagesima(year)
Quinquagesima(year)
AshWednesday(year)
PalmSunday(year)
GoodFriday(year)
Easter(year)
EasterSunday(year)
EasterMonday(year)
RogationSunday(year)
Ascension(year)
Pentecost(year)
PentecostMonday(year)
TrinitySunday(year)
CorpusChristi(year)
ChristTheKing(year)
Advent1st(year)
Advent2nd(year)
Advent3rd(year)
Advent4th(year)
ChristmasEve(year)
ChristmasDay(year)
BoxingDay(year)
NewYearsDay(year)
SolemnityOfMary(year)
Epiphany(year)
PresentationOfLord(year)
Annunciation(year)
TransfigurationOfLord(year)
AssumptionOfMary(year)
BirthOfVirginMary(year)
CelebrationOfHolyCross(year)
MassOfArchangels(year)
AllSaints(year)
AllSouls(year)
LaborDay(year)
CHBerchtoldsDay(year)
CHSechselaeuten(year)
CHAscension(year)
CHConfederationDay(year)
CHKnabenschiessen(year)
GBMayDay(year)
GBBankHoliday(year)
GBSummerBankHoliday(year)
GBMilleniumDay(year)
DEAscension(year)
DECorpusChristi(year)
DEGermanUnity(year)
DEChristmasEve(year)
DENewYearsEve(year)
FRFetDeLaVictoire1945(year)
FRAscension(year)
FRBastilleDay(year)
FRAssumptionVirginMary(year)
FRAllSaints(year)
FRArmisticeDay(year)
ITEpiphany(year)
ITLiberationDay(year)
ITAssumptionOfVirginMary(year)
ITAllSaints(year)
ITStAmrose(year)
ITImmaculateConception(year)
USDecorationMemorialDay(year)
USPresidentsDay(year)
USNewYearsDay(year)
USInaugurationDay(year)
USMLKingsBirthday(year)
USLincolnsBirthday(year)
USWashingtonsBirthday(year)
USMemorialDay(year)
USIndependenceDay(year)
USLaborDay(year)
USColumbusDay(year)
USElectionDay(year)
USVeteransDay(year)
USThanksgivingDay(year)
USChristmasDay(year)
USCPulaskisBirthday(year)
USGoodFriday(year)
CAVictoriaDay(year)
CACanadaDay(year)
CACivicProvincialHoliday(year)
CALabourDay(year)
CAThanksgivingDay(year)
CaRemembranceDay(year)
JPNewYearsDay(year)
JPGantan(year)
JPBankHolidayJan2(year)
JPBankHolidayJan3(year)
JPComingOfAgeDay(year)
JPSeijinNoHi(year)
JPNatFoundationDay(year)
JPKenkokuKinenNoHi(year)
JPGreeneryDay(year)
JPMidoriNoHi(year)
JPConstitutionDay(year)
JPKenpouKinenBi(year)
JPNationHoliday(year)
JPKokuminNoKyujitu(year)
JPChildrensDay(year)
JPKodomoNoHi(year)
JPMarineDay(year)
JPUmiNoHi(year)
JPRespectForTheAgedDay(year)
JPKeirouNOhi(year)
JPAutumnalEquinox(year)
JPShuubunNoHi(year)
JPHealthandSportsDay(year)
JPTaiikuNoHi(year)
JPNationalCultureDay(year)
JPBunkaNoHi(year)
JPThanksgivingDay(year)
JPKinrouKanshaNoHi(year)
JPEmperorsBirthday(year)
JPTennouTanjyouBi(year)
JPBankHolidayDec31(year)
}


\arguments{

    \item{year}{ 
        an integer value or vector of year numbers including the
        century. These are integers of the form \code{CCYY}, e.g. 
        \code{2000}.
        }
  
}


\value{

    Returns an ISO-8601 formatted calendar date \code{CCYYMMDD}, an
    object of class \code{"sdate"} which represents an integer
    value or vector.
   
}


\examples{
## no examples ...
}


\author{

    Diethelm Wuertz for this R-port.
    
}


\keyword{chron}


\eof
\name{xtsTools}

\alias{xjulian}
\alias{xdate}
\alias{xday.of.week}
\alias{xleap.year}

\alias{fxdata.contributors}
\alias{fxdata.parser}
\alias{fxdata.filter}
\alias{fxdata.varmin}

\alias{xts.log}
\alias{xts.diff}
\alias{xts.cut}
\alias{xts.interp}
\alias{xts.map}
\alias{xts.upsilon}
\alias{xts.dvs}
\alias{xts.dwh}


\title{Tools for FX High Frequency Data}


\description{
    
    A collection of functions for the management of high frequency 
    financial market time series, especially for FX series collected
    from a Reuters data feed. 
    This includes functions for the management of dates and times 
    formatted in the ISO-8601 string \code{CCYYMMDDhhmm},
    functions for filter and outlier detection of high 
    frequency FX data records as collected from a Reuters data feed,
    and functions which can be used to calculate log-prices, log-returns, 
    to extract subsamples, to interpolate in time, to build
    business time scales, and to de-seasonalize and de-volatilize
    high frequency financial market data.
    \cr
    
    
    \tabular{rll}{   
    		\tab
    		\tab	\bold{'CCYYMMDDhhmm' Dates and Times:} \cr
        1   \tab    \code{xjulian}      
            \tab    Julian minute counts for \code{CCYYMMDDhhmm} formats, \cr
        2   \tab    \code{xdate}        
            \tab    \code{CCYYMMDDhhmm} from Julian minute counts, \cr
        3   \tab    \code{xday.of.week}     
            \tab    day of week from \code{CCYYMMDDhhmm} dates/times, \cr
        4   \tab    \code{xleap.year}   
            \tab    Decides if \code{CCYYMMDDhhmm} is a leap year or not. \cr            
			\tab
			\tab	\cr
			\tab	
			\tab	\bold{Filter and Outlier detection:} \cr
        1   \tab    \code{fxdata.contributors}  
            \tab    Creates a table with contributor names, \cr  
        2   \tab    \code{fxdata.parser}        
            \tab    Parses FX contributors and delay times, \cr
        3   \tab    \code{fxdata.filter}        
            \tab    Filters price and spread values from FX records, \cr
        4   \tab    \code{fxdata.varmin}        
            \tab    Aggregates records to variable minutes format. \cr
    		\tab
			\tab	\cr
			\tab	
			\tab	\bold{De-Seasonalization and De-Volatilization:} \cr
        1   \tab    \code{xts.log}   
            \tab    Calculates logarithms for xts time series values, \cr
        2   \tab    \code{xts.diff}      
            \tab    Differentiates xts time series values with lag=1, \cr
        3   \tab    \code{xts.cut}   
            \tab    Cuts a piece out of a xts time series, \cr
        4   \tab    \code{xts.interp}  
            \tab    Interpolates for equidistant time steps, \cr
        5   \tab    \code{xts.map}   
            \tab    Creates a volatility adjusted time-mapping, \cr 
        6   \tab    \code{xts.upsilon} 
            \tab    Interpolates a time series in upsilon time, \cr
        7   \tab    \code{xts.dvs}   
            \tab    Creates a de-volatilizised time series, \cr
        8   \tab    \code{xts.dwh}   
            \tab    Plots intra-daily/weekly histograms. }  
                
}


\usage{
xjulian(xdates, origin = 19600101)
xdate(xjulians, origin = 19600101)
xday.of.week(xdates)
xleap.year(xdates)

fxdata.contributors(x, include = 10)
fxdata.parser(x, parser.table)
fxdata.filter(x, parameter = "strong", doprint = TRUE)
fxdata.varmin(x, digits = 4)

xts.log(xts)
xts.diff(xts)
xts.cut(xts, from.date, to.date)
xts.interp(xts, deltat = 1, method = "constant")
xts.map(xts, mean.deltat, alpha) 
xts.upsilon(xts, weekly.map = seq(from = 59, by =60, length = 168), 
    method = "constant", doplot = TRUE, \dots)
xts.dvs(xts, k, volatility, doplot = TRUE, \dots) 
xts.dwh(xts, deltat = 60, period = "weekly", dolog = TRUE, 
    dodiff = TRUE, doplot = TRUE) 
}


\arguments{

    \item{alpha}{
        the scaling exponent, a numeric value. For a random
        walk this will be 2.
        }
    \item{deltat}{
        the time in minutes between interpolated data points, 
        by default 1 minute.
        }
    \item{digits}{ 
        an integer value, the number of digits for the
        \code{BID} and \code{ASK} price. By default five.
        }
    \item{dolog, dodiff}{
        two logicals. Should the logarithm of the input data be taken?
        Should the difference of the input data be taken?
        Note, if both \code{dolog} and \code{dodiff} are set to true, 
        the input data are expected to be price values.
        }   
    \item{doplot}{
        a logical. Should a plot be displayed?
        }
    \item{doprint}{
        a logical, should the filter parameters be printed?
        }
    \item{from.date, to.date}{
        ISO-8601 start and end dates, [CCYYMMDD].
        }
    \item{include}{
        the contributors are sorted by frequency, the \code{include}
        market makers are slected, an integer value. By default 10.)
        }
    \item{k}{
        sampling frequency, an integer value. Takes values
        on a sequence of the order of 10 data points.
        }
    \item{mean.deltat}{
        the average size of the time intervals in minutes, an
        integer value.
        }
    \item{method}{
        a character string naming the interpolation method, either
        "linear" or "constant".
        }
    \item{origin}{
        the origin date of the counter, in ISO-8601 date format,
        [CCYYMMDDhhmm]. By default January 1st, 1960.
        }
    \item{parameter}{
        a character string, either \code{strong} or \code{weak}
        denoting the filter parameter settings.
        }
    \item{parser.table}{
        the table of contributors produced by \code{fxdata.contributors},
        a data.frame. In this table market leaders are marked.
        }
    \item{period}{
        a string, either "weekly", "daily" or "both" selecting the 
        type of the histogram. By default "weekly".
        }
    \item{volatility}{
        average volatility, a numeric value. Takes values
        of the order of the variance of the time series data.
        }
    \item{weekly.map}{
        an integer vector of time intervals, by default 168
        hourly intervals, spanning one week. Volatility
        based maps can be created by the function \code{xts.map}.
        }
    \item{x}{
        a 6 column standardized FX data frame with XDATE, DELAY, 
        CONTRIBUTOR, BID, ASKL and FLAG fields.
        }
    \item{xdates}{
        a numeric vector of ISO-8601 formatted Gregorian dates/times, \cr
        [CCYYMMDDhhmm].
        }
    \item{xjulians}{
        a numeric vector of Julian Minute Counts.
        }
    \item{xts}{
        a list with date/time \code{t} in ISO-8601
        format, [CCYYMMDDhhmm], and data values \code{x}.
        }
    \item{\dots}{
        arguments to be passed.
        }   
                
}


\value{
    
    \bold{Date and Time Functions:}
    \cr\cr
    
    \code{xjulian}
    \cr
    returns a numeric vector of Julian minute counts.
    \cr
    
    \code{xdates}
    \cr
    returns a numeric vector of ISO-8601 formatted dates/times, i.e.
    [CCYYMMDDhhmm].
    \cr
    
    \code{xday.of.week}
    \cr
    returns a numeric vector with entries  between \code{0} (Sunday) and 
    \code{6} (Saturday).
    \cr
    
    \code{xleap.year}
    \cr
    returns a logical vector with entries TRUE or FALSE, weather the date 
    falls in a leap year or not.
    \cr\cr
    
    
    \bold{Filter and Outlier Detection:}
    \cr\cr
    
    \code{fxdata.contributors}
    \cr
    returns a dataframe with the following columns: \code{CONTRIBUTOR}, 
    the code naming the contributor, a character string; \code{COUNTS}, 
    the counts, how often the contributor appeared in the file, an integer;
    \code{PERCENT}, the same in percent, a numeric value; \code{SELECT}, 
    a logical. If TRUE the contributor belongs to the group of the 
    \code{n} market makers, otherwise not.
    \cr
    
    \code{fxdata.parser}, \code{fxdata.filter}
    \cr
    return a data frame with the same structure as \code{x}, i.e. a 
    standardized FX high frequencey data file structure.
    \cr
    
    \code{fxdata.varmin}
    \cr
    return a data frame with the same structure as \code{x}, i.e. a 
    standardized FX high frequencey data file structure. The second column 
    named \code{DELAY} is not used and set to zero for each data record. The 
    third column \code{CONTRIBUTOR} is set to "MEAN", the method how the 
    variable minute record was evaluated. The last column \code{FLAG}
    count the number of values from which the variable minute data 
    record was evaluated.
    \cr\cr
    
    
    \bold{De-seasonalization and de-volatilization:}
    \cr\cr
    
    All functions beside \code{xts.map} and \code{xts.dwh} return a
    list with the following two components:
    \code{t}, the date/time in ISO8601 format, [CCYYMMDDhhmm], the same
    as the input data \code{xts$t},
    \code{x}, the logarithmic values of the input data records \code{xts$x}, 
    a numeric vector.
    \cr

    \code{xts.map}
    \cr
    returns list with the following two components:
    \code{xmap}, a numeric vector with the time intervals,
    \code{ymap}, a numeric vector, the values to be mapped.
    \cr

    \code{xts.dws}
    \cr 
    If \code{daily} was selected, a list with the following two 
    components is returned: 
    \code{td}, the daily histogram breaks,
    \code{xd}, the daily histogram freqencies.\cr
    If \code{weekly} was selected, a list with the following two 
    components is returned: 
    \code{tw}, the weekly histogram breaks,
    \code{xw}, the weekly histogram freqencies,\cr
    If \code{both} was selected, a list with all four components 
    is returned.
    
    
}


\details{

    \bold{Date and Time Functions:}
    \cr\cr
    Note, that the \code{x*} indicates "extended" Date format including 
    Time management functionality, whereas in \code{sjulian}, \code{sdate}, 
    etc. the \code{s*} indicates "standard" or "simple" Date format, 
    handling days, months years and centuries.
    \cr\cr
    
    \bold{The Data Preprocessing Process:}
    \cr\cr
    \code{fxdata.contributors} creates a contributor list from a 
    FX high frequency from a Reuters data feed and marks the market 
    leaders. \code{fxdata.parser} selects with the information from
    the contributors list data records from market leaders. As input
    serves a standardized high frequency data file. Then the function
    \code{fxdata.filter} filters the FX data records and finally
    the function \code{fxdata.varmin} creates a "variable 
    minutes" formatted data file, i.e. all data records within the same 
    minute are averaged. The preprocessed data are the starting point
    for further investiuagtions.
    \cr
    
    \bold{The Standardized FX high frequency data file structure:}
    \cr\cr
    \code{x} is a standardized data frame with 6 columns. The first 
    column gives the dates/time \code{XDATE} in ISO-8601 format 
    [CCYYMMDDhhmm], the second column is a measure for the feed 
    \code{DELAY}, the third column denotes the \code{CONTRIBUTOR} 
    code, the fifth and six columns are the \code{BID} and \code{ASK} 
    price, and the last column is an information \code{FLAG}, to 
    add additional information. 
    \cr

    \bold{The Contributor List:}
    \cr\cr
    The output of the \code{fxdata.contributors} function is used 
    as input for the function 
    \code{fxdata.parser}, which allows to extract the contributors 
    marked as market makers in the output table.
    \cr
    
    \bold{The Parser:}
    \cr\cr
    The functions \code{fxdata.parser} parses the data.
    The parser table, \code{parser.table}, is a data frame with 4 
    columns: \code{CONTRIBUTOR} denotes a code naming the contributor, 
    \code{COUNTS} gives the number of counts, how often the contributor 
    appeared in the file, \code{PERCENT} the same as a percent value,
    \code{SELECT} denotes a logical valie, if TRUE the contributor 
    belongs to the group of the market makers, otherwise not.
    \cr
    
    \bold{Varaiable Minutes Formatted Files:}
    \cr\cr
    The function \code{fxdata.varmin}
    creates data records within a variable minutes format.
    
    \bold{Log Prices and Log Returns:}
    \cr\cr
    The function \code{xts.log} is mainly used to create log-prices from 
    high frequency price records and the function \code{xts.diff}
    is used to create log-returns. 
    \cr
  
    \bold{Subsamples:}
    \cr\cr
    Th function \code{xts.cut} is mainly used to create a subsample from
    data records. If the start and/or end date are out of the time range 
    the time series is simply forward/backward extrapolated with the first 
    and/or last value.
    \cr
  
    \bold{Interpolation:}
    \cr\cr
    The function \code{xts.interp} is used to interpolate data records. 
    The method allows for two different kinds of interpolations, either 
    \code{"linear"} for a linear interpolation or \code{"constant"} for 
    a constant interpolation keeping the previous value in time (left 
    value) within the interpolation region.
    \cr
  
    \bold{Business Time Maps:}
    \cr\cr
    The function \code{xts.map} is mainly used to create the time map 
    required by the 
    function \code{xts.upsilon}. Important: The argument \code{xts} must 
    start on a Monday and end on a Sunday. Use \code{xts.cut} to guarantue 
    this.
    \cr
  
    \bold{De-Seasonalization:}
    \cr\cr
    The function \code{xts.upsilon} is  used to create data records with 
    volatility 
    adjusted time steps obtained from the "upsilon time" approach. These 
    time steps can be taken from the time map crreated by the function 
    \code{xts.map}. The data records are interpolated according to this 
    time schedule.
    \cr
  
    \bold{De-Volatilization:}
    \cr\cr
    The de-volatilization algorithm is based on Zhou's approach. The
    algorithm used by the function \code{xts.dvs} reduces the sample
    frequency by keeping the variance of 
    the price changes constant, therefore the name "de-volatilization". 
    The procedure removes volatility by sampling data at different dates 
    for different times. When the market is highly volatile more data are
    sampled. Equivalently, the time is stretched. When the market is
    less volatile, less data are sampled. Equivalently, the time is
    compressed. Although the resulting subsequence has unequally space
    calendar date/time intervals, it produces an almost equally volatile
    time series. This time series is called a de-volatilized time
    series, or "dv-Series".
    \cr
  
    \bold{Daily/Weekly Historgram Plots:}
    \cr\cr
    Financial market data exhibit seasonal structures over the day or 
    week. This can be made explicit by daily or weekly histogram plots 
    of the data using the function \code{xts.dwh}.
    
}


\notes{

    These functions were written originally for R Version 1.5. Only
    minor changes were made to make these functions available for
    Version 1.9. Date and time classes are outdated, but the functions
    are still working.
    
    The file \code{fdax97m.csv} is too large and therefore not part of 
    the \code{fBasics} distribution. Please contact \emph{inf@rmetrics.org}.
    
}


\author{

    Diethelm Wuertz for this \R-port.
    
}


\references{

ISO-8601 (1988); 
    \emph{Data Elements and Interchange Formats -
    Information Interchange, Representation of Dates and Time},
    International Organization for Standardization,
    Reference Number ISO 8601, 14 pages.

Zhou B. (1995);
    \emph{Forecasting Foreign Exchange Rates Subject to De-volatilization}, 
    in: Freedman R.S., Klein A.R., Lederman J. eds., Artificial Intelligence 
    in the Capital Markets, Irwin Publishing, Chicago, p. 137--156.

Guillaume D.M., Dacorogna M.M., Dave R.R., Mueller U.A., Olsen R.B., 
    Pictet O.V. (1997); 
    \emph{From the bird's eye to the microscope: 
    a survey of new stylized facts of the intra-daily foreign 
    exchange markets}, 
    Finance and Stochastics 1, 95--129.
        
}


\examples{
## xjulian - 
   xmpBasics("\nStart: Julian Counts > ")
   # Return the number of minute counts for the last day in every 
   # month for year 2000 beginning January 1st, 2001 at 16:00:
   xjulian(c(20000131, 20000229, 20000331, 20000430, 20000531, 20000630,
     20000731, 20000831, 20000930, 20001031, 20001130, 20001231)*10000+1600,
     origin = 20000101)
     
## xdate - 
   xmpBasics("\nNext: Convert Julian Counts to Dates > ")
   # Return the number of minute counts for th
   # Manage Date/Time in Extended Date/Time Format, ISO-8601
   # Date: 1973-01-01 15:30
   xjulian(197301011530)
   print(xdate(xjulian(197301011530)), digits = 9)
  
## xday.of.week -
   # Calculate the day of week for 1973-01-01 16:15
   xmpBasics("\nNext: Compute Day of Week > ")
   xday.of.week(197301011615)
        
## xleap.year -
   xmpBasics("\nNext: Check for Leap Years > ")
   # Falls Februar 1st, 2000 16:15 in a leap year?
   xleap.year(200002011615)    
   
## fxdata.contributors - 
   xmpBasics("\nStart: Filter Contributors > ")
   # Print contributor list:
   data(usdthb)
   usdthb[1:25, ]
   # Create contributor list:
   fxdata.contributors(usdthb, include = 5)
   
## fxdata.parser - 
   xmpBasics("\nNext: Parse Records > ")
   # Parse data:
   # Create a contributor list and mark the first 5 market makers:
   parser.table = fxdata.contributors(usdthb, include=5)
   # Parse the market makers and print the first 25 entries:
   fxdata.parser(usdthb, parser.table)[1:25,]
   
## fxdata.filter - 
   xmpBasics("\nNext: Filter Records > ")
   # Filter data and plot unfiltered data:
   par(mfrow = c(2, 1))
   NumberOfRecords = length(usdthb[,1])
   NumberOfRecords
   plot(usdthb[,4], type="l", 
        xlab = "Tick Number from Reuters THB=", 
        ylab = "100*log(Bid[n]/Bid[1])      Bid",
        ylim = c(-20,30), main="USDTHB June 1997 unfiltered")
   lines(x=c(1, NumberOfRecords), y=rep(usdthb[1,4], 2), col = 4)
   lines(-100*log(usdthb[1,4]/usdthb[,4]))
   lines(x = c(1, NumberOfRecords), y = c(0, 0), col = 4)
   # Filter the data:
   usdthb = fxdata.filter(usdthb, parameter="strong")
   # Quick And Dirty Time Scaling
   Records = length(usdthb$accepted[,4])
   scale = NumberOfRecords/Records
   # Plot filtered data:
   plot(x=(1:Records)*scale, y=usdthb$accepted[, 4], type = "l", 
        xlab = "Tick Number from Reuters THB=", 
        ylab = "100*log(Bid[n]/Bid[1])      Bid", 
        ylim = c(-20,30), main="USDTHB June 1997 filtered")
   y = rep(usdthb$accepted[1, 4], 2)
   lines(x=c(1, NumberOfRecords), y=y, col=4)
   y = -100*log(usdthb$accepted[1, 4]/usdthb$accepted[, 4])
   lines(x = (1:Records)*scale, y=y)
   lines(x = c(1, NumberOfRecords), y = c(0, 0), col = 4)
   
## fxdata.varmin - 
   xmpBasics("\nNext: Variable Minute Records > ")
   # Variable Minute Records from filter accepted Data,
   # create a varmin file and print the first 25 entries:
   fxdata.varmin(usdthb$accepted, digits = 5)[1:25, ]  
   
## xts.log - 
   xmpBasics("\nStart: Log Prices of FX Data > ")
   # Calculate log-prices from AUDUSD bid prices
   options(digits = 10)
   data(audusd)
   prices = list(t = audusd[,"XDATE"], x = audusd[,"BID"])
   # Print the first 25 entries:
   log.prices = xts.log(prices)
   as.data.frame(log.prices)[1:25, ]
   
## xts.diff - 
   xmpBasics("\nNext: Returns of FX Data > ")
   # Calculate one hourly AUDUSD log-returns
   prices = list(t = audusd[,"XDATE"], x = audusd[,"BID"])
   # Calculate the returns and print the first 25 entries:
   data.frame(xts.diff(xts.log(prices)))[1:25, ]
   
## xts.cut - 
   xmpBasics("\nNext: Cut out a Piece From a FX File > ")
   # Retrieve the AUDUSD bid quotes for October 21, 1997, 16:00 
   prices = list(t = audusd[,"XDATE"], x = audusd[,"BID"])
   # Retrieve prices and print the first 25 entries:
   data.frame(xts.cut(prices, from.date = 19971021, 
   	 to.date = 19971021))[1:25,]

## xts.interp - 
   xmpBasics("\nNext: Interpolate of FX Data > ")
   # Interpolate AUDUSD bid prices 
   # on a 15 minutes  time scale for October 21, 1997:
   prices = list(t = audusd[,"XDATE"], x = audusd[,"BID"])
   # Interpolate the prices and print the first 25 entries:
   data.frame(xts.interp(prices, deltat = 15))[1:25, ]
   
## xts.map - 
   xmpBasics("\nNext: Create Business Time Map > ")
   options(object.size = 5e8)
   par(mfrow = c(2, 1))
   # Load and plot prices:
   data(fdax9710)
   index = list(t = fdax9710[,"XDATE"], x = fdax9710[,"FDAX"])  
   # Start on Monday - end on Sunday, 3 weeks:
   index = xts.cut(index, from.date=19971006, to.date=19971026)
   plot(index$x, type = "l", xlab = "Prices", main = "Prices in event time")   
   # Create hourly upsilon time map - start on Monday - end on Sunday:
   tmap = xts.map(index, mean.deltat = 60, alpha = 1.05)
   plot(x = tmap$xmap, y = tmap$ymap, ylim = c(0, max(tmap$x)), type="l", 
     main = "Time Mapping")   
   tmap 
   
## xts.upsilon -  
   xmpBasics("\nNext: De-seasonalize in Upsilon Time > ")
   index = list(t = fdax9710[,"XDATE"], x = fdax9710[,"FDAX"])  
   # Start on Monday - end on Sunday, 3 weeks:
   index = xts.cut(index, from.date = 19971006, to.date = 19971026)
   plot(index$x, type = "l", xlab = "Prices", main = "Prices in event time")   
   # Create hourly upsilon time map - start on Monday - end on Sunday:
   tmap = xts.map(index, mean.deltat = 60, alpha = 1.05)
   # Extract data records according to time map:
   index.ups = xts.upsilon(index, weekly.map = tmap$ymap, 
     main="Prices in Upsilon time")
    
## xts.dvs - 
   xmpBasics("\nNext: De-volatilize Time Series > ")
   index = list(t=fdax9710[,"XDATE"], x=fdax9710[,"FDAX"])  
   # Start on Monday - end on Sunday, 3 weeks:
   index = xts.cut(index, from.date=19971006, to.date=19971026)
   plot(index$x, type = "l", ylab = "Prices", main = "Prices in event time")    
   # Devolatilize Time Series With dv-Series Algorithm:
   index.dvs = xts.dvs(index, k = 8, 
     volatility = 13.15*var(diff(log(index$x))), main = "Prices from dv-series") 

\dontrun{
## xts.dws -
   xmpBasics("\nNext: Plot daily/weekly Charts > ")
   # NOTE:
   # The file \code{fdax97m.csv} is too large and therefore not part 
   # of  this distribution. Please contact \emph{inf@rmetrics.org}.
   data(fdax97m)
   xts = list(t = fdax97m[,"XDATE"], x = fdax97m[,"FDAX"])
   # Start on Monday - end on Sunday, 3 weeks:
   xts = xts.cut(index, from.date = 19970106, to.date = 19971228)
   # Create Daily and Weekly Histograms:
   result = xts.dwh (xts, period = "both", dolog = TRUE, 
     dodiff = TRUE, deltat = 30, doplot = TRUE)
}      
}


\keyword{data}


\eof
\name{fBasicsTools}


\alias{fBasicsTools}

\alias{myFinCenter}
\alias{myUnits}
\alias{currentYear}

\alias{xmpBasics}
\alias{xmpfBasics}

\alias{modify}
\alias{modify.default}
\alias{atoms}
\alias{atoms.default}

\title{fBasics Tools}


\description{

	Tools used in the fBasics library.
	
}


\usage{
myFinCenter
currentYear

xmpfBasics()
xmpBasics(prompt = "")
}


\arguments{

  	\item{currentYear}{
  		the current year, formatted as \code{CCYY}.
  		}
  	\itam{myFinCenter}{
  		a character string denoting my financial center settings,
  		by default \code{"Zurich"}.
  		}
  	\itam{myUnits}{
  		a character string denoting current time units, one from
  		"secs", "mins", "hours", "days", or "weeks".
  		}
  	\item{prompt}{
		the string printed when prompting the user for input. 
		}	
}


\value{
  
	xmpfBasics
	\cr
	Popups the example menu.
	\cr
	
	xmpBasics
	\cr
	Nothing, the default, or the the prompt if you have set
	\code{xmpBasics = readline} on the command prompt. 
	
}


\notes
{
	The example in the manual pages may be interactive and ask for
	input from the user. To achieve this you have to type on the
	command line: \code{xmpBasics = readline}

}


\author{

	Diethelm Wuertz for this R-Port.

}


\examples{
## no examples ...
}


\keyword{programming}


\eof
\name{fBasicsData}

\alias{fBasicsData}

\alias{audusd}
\alias{bmwres}
\alias{fdax9710}
\alias{nyseres}
\alias{usdthb}

\alias{timezones.db}


\title{fBasics Data Sets}


\description{

	A collection of Data Sets used in the examples of the \code{fBasics}
	library.
	\cr
	
	The data sets are:
	
	\tabular{rll}{	
	 	1	\tab	\code{audusd.csv} 	
	 		\tab 	Reuters Tick-by-Tick AUDUSD rates 1997-10, \cr
	 	2	\tab	\code{usdthb.csv} 	
	 		\tab 	Reuters Tick-by-Tick USDTHB rates 1997, \cr
     	3	\tab	\code{fdax9710.csv} 	
     		\tab 	Minute-by-Minute DAX Futures Prices for 1997-10*, \cr
     	4	\tab	\code{fdax97m.csv} 	
     		\tab 	Minutely Time and Sales DAX Futures for 1997, \cr
     	5	\tab	\code{bmwres.csv} 	
     		\tab 	Daily log Returns of German BMW Stock Proces, \cr
     	6	\tab	\code{nyseres.csv} 	
     		\tab 	Daily log Returns of the NYSE Composite Index. }
     		
    *The file \code{fdax97m.csv} is too large and therefore not part of 
    the \code{fBasics} distribution. Please contact \emph{inf@rmetrics.org}.
    
     		
	Additionally the timezone datafile is:
	
	\tabular{rll}{
	 	1	\tab	\code{timezones.db} 	
	 		\tab 	file with all available Ical time zone names. }
	
}


\details{

	\bold{High Frequency Data for the AUDUSD and USDTHB:}
	\cr\cr
	\code{audusd} and \code{usdthb} archive high frequency exchange rates 
	for the Australian / US Dollar exchange rate in October 1997 and exchange 
	rates for the US Dollar / Thailand Bhat exchange rate in June 1997:
	A comma delimited CSV file with 6 columns. The first column,
	named \code{XDATE}, contains date/time entries in ISO-8601 format 
	as [CCYYMMDDhhmm], the second column, named \code{DELAY}, gives 
	the delay in minutes between the time stamp of Reuter's data
	record and arrival time at the local database, the third column
	named \code{CONTRIBUTOR} is Reuter's identification, a 4 character
	code, the fourth and fifth column, named \code{BID} and \code{ASK}
	are the bid and ask price quotations, and finally the sixth
	column, named \code{FLAG}, is not used and has zeros as entries.
	\cr
	
	\bold{DAX Futures Data:}
	\cr\cr
	\code{fdax9710} archives returns of minute-by-minute prices for 
	Dax Futures in October 1997:
	A comma delimited CSV file with 2 columns. The first column,
	named \code{XDATE}, contains date/time entries in ISO-8601 format 
	as [CCYYMMDDhhmm], the second column, named \code{FDAX}, gives 
	an averaged price of the Dax Futures, i.e. the mean of
	all volume weighted time and sales within the same minute.
	\cr
	\code{fdax97m} archives returns for minute-by-minute prices for Dax 
	Futures in 1997: A comma delimited CSV file with 2 columns. The first 
	column, named \code{XDATE}, contains date/time entries in ISO-8601 
	format as [CCYYMMDDhhmm], the second column, named \code{FDAX}, gives 
	a minutely averaged price during opening hours of the exchange, 
	i.e. the mean of all volume weighted time and sales within the 
	same minute.
	\cr
	
	\bold{Log returns for BMW Shares and NYSE Composite Index:}
	\cr\cr
	\code{bmwres} and \code{nyseres} archive log returns of the German 
	BMW stock listed in the German  DAX30 and log returns of the NYSE 
	Composite Index, both on a daily trading day time scale just numbering 
	the log returns: A one column CSV file with column names \code{BMW} 
	or \code{NYSERES}, respectively. The entries are the differences
	of the logarithmic prices on two succeeding trading days.
	\cr
	
	\bold{Calendar Data:}
	\cr\cr
	\code{holidays.db.R} is the database of world wide holidays with
	informations collected from several sources on the internet.
	\cr
    \code{timezones.csv} is a list of timezones information extracted
    from Olsen's database. Downloadable from
    \cr
    \emph{ftp://elsie.nci.nih.gov/pub/}
 	
}


\source{

	
	\code{audusd}\cr
	\code{usdthb}
	\cr
	The data were collected by D. Wuertz and R. Schnidrig from the 
	Reuter's data feed.
	
	\code{fdax9710}\cr
	\code{fdax97m}
	\cr
	The data were extracted from time and sales data records from
	the Frankfurt Futures Exchange.
	
	\code{bmwres}
	\cr
	The data were published in the EVIS software package.
	
	\code{nyseres}
	\cr
	The data were downloaded from the web site of the New York Stock 
	Exchange and the residuals were calculated as logarithmic price 
	differences.\cr
	\emph{http://www.nyse.com}.
	
}


\examples{
##  plot -
    xmpBasics("\nStart: Plot Residuals NYSE Composite Index > ")
    data(nyseres)
    x = as.ts(nyseres)
    par(mfrow = c(2, 1), cex = 0.75)
	plot(100*x, type = "l", col = "steelblue4",
	  main = "NYSE Composite Index")
	grid()
	plot(cumsum(x), type = "l", col = "steelblue4",
	  main = "Cumulated NYSE Index")
	grid()
}


\keyword{datasets}


\eof
\name{MoFiTSData}

\alias{MoFiTSData}

\alias{CPI.dat}
\alias{DowJones30}
\alias{highFreq3M.df}
\alias{IP.dat}
\alias{lexrates.dat}
\alias{msft.dat}
\alias{shiller.annual}
\alias{shiller.dat}
\alias{singleIndex.dat}
\alias{varex.ts}
\alias{yhoo.df}


\title{fBasics Data Sets from MoFiTS}


\description{
        
     Data sets used for the examples from the book "Modeling Financial 
     Time Series with S-Plus" by E. Zivot and J. Wang.
     
     The data sets are:
     
     \tabular{rll}{
        1   \tab    \code{CPI.dat}  
            \tab    Seasonally adjusted US Consumer Price Index, \cr 
        2   \tab    \code{DowJones30.csv}   
            \tab    Dow Jones Industrial Average Index, \cr 
        3   \tab    \code{highFreq3M.df}    
            \tab    3M High Frequency Stock Market Data, \cr
        4   \tab    \code{IP.dat}   
            \tab    Seasonally Adjusted US Industrial Production Index, \cr              
        5	\tab	\code{lexrates.dat}
        	\tab	Spot and Forward Exchange Rate Data, \cr
       	6   \tab    \code{msft.dat}     
            \tab    Open, High, Low, Close of Microsoft Stocks, \cr
        7   \tab    \code{shiller.dat}    
            \tab    Robert Shiller's Monthly Economic Data Set, \cr 
        8	\tab	\code{shiller.annual}
        	\tab	Robert Shiller's Monthly Economic Data Set, \cr
        9   \tab    \code{singleIndex.dat.csv}  
            \tab    Microsoft Stocks and SP500 Index Data, \cr 
        10 	\tab	\code{varex.ts.csv}
        	\tab	Real Stock Returns and Output Growth Data, \cr
        11  \tab    \code{yhoo.df}  
            \tab    Yahoo Stock Information. }      
                        
}


\details{


    \bold{Dow Jones Industrial Average:}
    \cr\cr
    The file \code{DowJones30.csv} contains closing prices for the 
    30 stocks represented in the Dow Jones Industrial Average Index. 
    \cr
    Data are downloadable and can be updated from Yahoo's web site. 
    \cr
    

    \bold{Microsoft Stocks and SP500 Index Data:}
    \cr\cr
    The file \code{singleIndex.dat.csv} contains the monthly closing 
    prices for Microsoft Corporation and the SP 500 index.
    \cr
    Data are downloadable and can be updated from Yahoo's web site.
    \cr
 
    
    \bold{Open, High, Low, Close of Microsoft Stocks:}
    \cr\cr
    The file \code{msft.dat.csv} contains data representing the open, 
    high, low, close and volume information for Microsoft stocks. 
    \cr
    Data are downloadable and can be updated from Yahoo's web site.
    \cr
    
    
    \bold{IP and CPI Index Data:}
    \cr\cr
    The file \code{IP.dat.csv} contains data representing seasonally 
    adjusted US Industrial Production Index and the file 
    \code{CPI.dat.csv} contains data representing seasonally 
    adjusted US Consumer Price Index. 
    \cr
    Data are downloadable and can be updated from Economagics's web site. 
    \cr
    
        
    \bold{3M high Frequency Data:}
    \cr\cr
    The file \code{highFreq3M.df.csv} holds Tsay's data for 3M. Date 
    information is expressed as the day of the month and the number of 
    seconds from midnight Data is for December 1999. Columns are: day - 
    integer representing the trading day of the month, sec - trade.time 
    integer representing the trading time recorded as the number of 
    seconds from midnight, price transaction price in dollars. Downloadable
    from:
    \cr
    \emph{http://www.gsb.uchicago.edu/fac/ruey.tsay/teaching/fts}
    \cr
    
    
    \bold{Spot and Forward Exchange Rate Data:}
    \cr\cr
    The file \code{lexrates.dat.csv} holds log spot exchange and 
    forward exchange rates between 
    \code{USCNS, USCNF} -  USD and CAD, Canadian Dollar,
    \code{USDMS, USDMF} -  USD and DEM, Deutsche Mark,
    \code{USFRS, USFRF} -  USD and FFR, French Franc,
    \code{USILS, USJYF} -  USD and JPY, Italian Lira, and 
    \code{USUKS, USUKF} -  USD and GBP, Japanese Yen.
    \cr
    \emph{Source: Thompson Financial, formerly Datastream}, see also:
    \emph{Zivot, E. (2000) Cointegration and forward and spot exchange 
    	rate regressions, Journal of International Money and Finance, 
    	19, 387--401 and 785--812.}
    \cr
    
    
    \bold{Robert Shillers Monthlly and Annual Economic Data:}
    \cr\cr
    The files \code{shiller.dat.csv} and \code{shiller.annual.csv} hold
	data used in the book "Irrational Exuberance" by Robert Shiller. The 
	data are 
	\code{price} - monthly nominal US SP stock market prices,
	\code{dividend} - nominal SP Composite Index dividends,
	\code{earnings} - nominal SP Composite Index earnings,
	\code{cpi} - US Consumer Price Indexes,
	\code{real.price} - real US stock market prices,
	\code{real.dividend} - real SP Composite Index dividends,
	\code{real.earnings} - real SP Composite Index earnings,
	\code{pe.10} - price-earnings ratios,
	\code{dp.ratio} - dividend-price ratios,
	\code{dp.yield} - dividend-price yield. The last two are only 
	listed in \code{shiller.annual}.
	The series start January 1871 and end on March 2001.
	Data are available from:
    \cr
    \emph{Shiller, R.J. (1989) Market Volatility, MIT Press.}\cr
	\emph{Shiller, R.J. (2001) Irrational Exuberance, Broadway Books.}
	\cr
	
	    
    \bold{Yahoo Stock Information:}
    \cr\cr  
    The file \code{yhoo.df.csv} contains data representing daily 
    transaction information of Yahoo stock, with the following 
    six columns: Date, Open, High, Low, Close, Volume.
    \cr
    Data are downloadable and can be updated from Yahoo's web site.
    
    
    \bold{Real Stock Returns and Output Growth Data:}
    \cr\cr  
    The file \code{varex.ts.csv} contains real stock returns and output 
	growth data. The column MARKET.REAL lists continuously compounded 
	real returns on the SP500 index, the column RF.REAL lists real 
	interest rates of 30-day US Treasury Bills, the column INF lists
	continuously compounded growth rate of US CPI, and the column
	IPG lists continuously compounded growth rate of US industrial 
	production. The data are monthly starting December 1959 and 
	ending December 2000.
    \cr
    Data are downloadable and can be updated from Economagic's web site.
    	
}

\examples{
## no examples ...
}


\keyword{datasets}


\eof
\name{funBasics}

\alias{funBasics}


\title{Demo Function Addon}


\description{
        
     A collection of functions written as examples and listed
     in the demo file "funBasics".
     
     The functions are:
     
     \tabular{rll}{
         1  \tab    \code{print.dates}  
            \tab    S3 print mehtod for objects of class "dates", \cr 
         2  \tab    \code{print.chron}   
            \tab    S3 print mehtod for objects of class "chron", \cr 
         3  \tab    \code{seq.chron}    
            \tab    SPlus like "seq.dates" function, \cr
            
         4  \tab    \code{dssd}   
            \tab    Density using smoothing spline ANOVA model, \cr              
         5	\tab	\code{pssd}
        	\tab	Probability using smoothing spline ANOVA model, \cr
       	 6  \tab    \code{qssd}     
            \tab    Quantiles using smoothing spline ANOVA model, \cr
         7  \tab    \code{rssd}    
            \tab    Random Deviates using smoothing spline ANOVA model, \cr 
         8	\tab	\code{ssdFit}
        	\tab	Parameter Fit using smoothing spline ANOVA model, \cr
        	
         9  \tab    \code{bootMean}  
            \tab    Bootstrapped mean to get Confidence Intervals, \cr 
            
        10 	\tab	\code{data.csv, csvImport}
        	\tab	Imports data from comma delimited CSV files, \cr
        11 	\tab	\code{forecastsImport}
        	\tab	Downloads Monthly Market Data from "www.forecasts.org", \cr
        	
        12 	\tab	\code{is.weekday}
        	\tab	Test if a date is a weekday day or not, \cr\
        13 	\tab	\code{is.weekend}
        	\tab	Test if a date is a weekend day or not, \cr
        14 	\tab	\code{is.bizday}
        	\tab	Test if a date is a business day or not, \cr
        15 	\tab	\code{holiday.ZURICH}
        	\tab	Holiday Calendar for Zurich in Switzerland, \cr
        16 	\tab	\code{summary.timeSeries}
        	\tab	S3 Summary method for objects of class "timeDate". }   
                        
}


\examples{
## no examples ...
}


\keyword{programming}


\eof
